@@ -120,8 +120,9 @@ class IssueRole(object):
                 )
             else:
                 raise ValueError(
-                    "Neither {} nor issues_github_path "
-                    "is set".format(self.uri_config_option)
+                    "Neither {} nor issues_github_path is set".format(
+                        self.uri_config_option
+                    )
                 )
             issue_text = self.format_text(issue_no)
             link = nodes.reference(text=issue_text, refuri=ref, **options)
