@@ -9,10 +9,10 @@ kind of confidence on the prediction. This example demonstrates how to
 visualize how well calibrated the predicted probabilities are using calibration
 curves, also known as reliability diagrams. Calibration of an uncalibrated
 classifier will also be demonstrated.
-"""
-print(__doc__)
-# %%
 
+"""
+
+# %%
 # Author: Alexandre Gramfort <alexandre.gramfort@telecom-paristech.fr>
 #         Jan Hendrik Metzen <jhm@informatik.uni-bremen.de>
 # License: BSD 3 clause.
@@ -29,11 +29,13 @@ print(__doc__)
 from sklearn.datasets import make_classification
 from sklearn.model_selection import train_test_split
 
-X, y = make_classification(n_samples=100_000, n_features=20, n_informative=2,
-                           n_redundant=10, random_state=42)
+X, y = make_classification(
+    n_samples=100_000, n_features=20, n_informative=2, n_redundant=10, random_state=42
+)
 
-X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.99,
-                                                    random_state=42)
+X_train, X_test, y_train, y_test = train_test_split(
+    X, y, test_size=0.99, random_state=42
+)
 
 # %%
 # Calibration curves
@@ -62,33 +64,40 @@ from sklearn.calibration import CalibratedClassifierCV, CalibrationDisplay
 from sklearn.linear_model import LogisticRegression
 from sklearn.naive_bayes import GaussianNB
 
-lr = LogisticRegression(C=1.)
+lr = LogisticRegression(C=1.0)
 gnb = GaussianNB()
-gnb_isotonic = CalibratedClassifierCV(gnb, cv=2, method='isotonic')
-gnb_sigmoid = CalibratedClassifierCV(gnb, cv=2, method='sigmoid')
+gnb_isotonic = CalibratedClassifierCV(gnb, cv=2, method="isotonic")
+gnb_sigmoid = CalibratedClassifierCV(gnb, cv=2, method="sigmoid")
 
-clf_list = [(lr, 'Logistic'),
-            (gnb, 'Naive Bayes'),
-            (gnb_isotonic, 'Naive Bayes + Isotonic'),
-            (gnb_sigmoid, 'Naive Bayes + Sigmoid')]
+clf_list = [
+    (lr, "Logistic"),
+    (gnb, "Naive Bayes"),
+    (gnb_isotonic, "Naive Bayes + Isotonic"),
+    (gnb_sigmoid, "Naive Bayes + Sigmoid"),
+]
 
 # %%
 fig = plt.figure(figsize=(10, 10))
 gs = GridSpec(4, 2)
-colors = plt.cm.get_cmap('Dark2')
+colors = plt.cm.get_cmap("Dark2")
 
 ax_calibration_curve = fig.add_subplot(gs[:2, :2])
 calibration_displays = {}
 for i, (clf, name) in enumerate(clf_list):
     clf.fit(X_train, y_train)
     display = CalibrationDisplay.from_estimator(
-        clf, X_test, y_test, n_bins=10, name=name, ax=ax_calibration_curve,
-        color=colors(i)
+        clf,
+        X_test,
+        y_test,
+        n_bins=10,
+        name=name,
+        ax=ax_calibration_curve,
+        color=colors(i),
     )
     calibration_displays[name] = display
 
 ax_calibration_curve.grid()
-ax_calibration_curve.set_title('Calibration plots (Naive Bayes)')
+ax_calibration_curve.set_title("Calibration plots (Naive Bayes)")
 
 # Add histogram
 grid_positions = [(2, 0), (2, 1), (3, 0), (3, 1)]
@@ -97,8 +106,11 @@ for i, (_, name) in enumerate(clf_list):
     ax = fig.add_subplot(gs[row, col])
 
     ax.hist(
-        calibration_displays[name].y_prob, range=(0, 1), bins=10, label=name,
-        color=colors(i)
+        calibration_displays[name].y_prob,
+        range=(0, 1),
+        bins=10,
+        label=name,
+        color=colors(i),
     )
     ax.set(title=name, xlabel="Mean predicted probability", ylabel="Count")
 
@@ -128,8 +140,14 @@ from collections import defaultdict
 
 import pandas as pd
 
-from sklearn.metrics import (precision_score, recall_score, f1_score,
-                             brier_score_loss, log_loss, roc_auc_score)
+from sklearn.metrics import (
+    precision_score,
+    recall_score,
+    f1_score,
+    brier_score_loss,
+    log_loss,
+    roc_auc_score,
+)
 
 scores = defaultdict(list)
 for i, (clf, name) in enumerate(clf_list):
@@ -204,15 +222,17 @@ class NaivelyCalibratedLinearSVC(LinearSVC):
 
 # %%
 
-lr = LogisticRegression(C=1.)
+lr = LogisticRegression(C=1.0)
 svc = NaivelyCalibratedLinearSVC(max_iter=10_000)
-svc_isotonic = CalibratedClassifierCV(svc, cv=2, method='isotonic')
-svc_sigmoid = CalibratedClassifierCV(svc, cv=2, method='sigmoid')
+svc_isotonic = CalibratedClassifierCV(svc, cv=2, method="isotonic")
+svc_sigmoid = CalibratedClassifierCV(svc, cv=2, method="sigmoid")
 
-clf_list = [(lr, 'Logistic'),
-            (svc, 'SVC'),
-            (svc_isotonic, 'SVC + Isotonic'),
-            (svc_sigmoid, 'SVC + Sigmoid')]
+clf_list = [
+    (lr, "Logistic"),
+    (svc, "SVC"),
+    (svc_isotonic, "SVC + Isotonic"),
+    (svc_sigmoid, "SVC + Sigmoid"),
+]
 
 # %%
 fig = plt.figure(figsize=(10, 10))
@@ -223,13 +243,18 @@ calibration_displays = {}
 for i, (clf, name) in enumerate(clf_list):
     clf.fit(X_train, y_train)
     display = CalibrationDisplay.from_estimator(
-        clf, X_test, y_test, n_bins=10, name=name, ax=ax_calibration_curve,
-        color=colors(i)
+        clf,
+        X_test,
+        y_test,
+        n_bins=10,
+        name=name,
+        ax=ax_calibration_curve,
+        color=colors(i),
     )
     calibration_displays[name] = display
 
 ax_calibration_curve.grid()
-ax_calibration_curve.set_title('Calibration plots (SVC)')
+ax_calibration_curve.set_title("Calibration plots (SVC)")
 
 # Add histogram
 grid_positions = [(2, 0), (2, 1), (3, 0), (3, 1)]
@@ -238,8 +263,11 @@ for i, (_, name) in enumerate(clf_list):
     ax = fig.add_subplot(gs[row, col])
 
     ax.hist(
-        calibration_displays[name].y_prob, range=(0, 1), bins=10, label=name,
-        color=colors(i)
+        calibration_displays[name].y_prob,
+        range=(0, 1),
+        bins=10,
+        label=name,
+        color=colors(i),
     )
     ax.set(title=name, xlabel="Mean predicted probability", ylabel="Count")
 
