@@ -10,6 +10,7 @@ classes. Arrows point from the probability vectors predicted by an uncalibrated
 classifier to the probability vectors predicted by the same classifier after
 sigmoid calibration on a hold-out validation set. Colors indicate the true
 class of an instance (red: class 1, green: class 2, blue: class 3).
+
 """
 
 # %%
@@ -34,8 +35,9 @@ from sklearn.datasets import make_blobs
 
 np.random.seed(0)
 
-X, y = make_blobs(n_samples=2000, n_features=2, centers=3, random_state=42,
-                  cluster_std=5.0)
+X, y = make_blobs(
+    n_samples=2000, n_features=2, centers=3, random_state=42, cluster_std=5.0
+)
 X_train, y_train = X[:600], y[:600]
 X_valid, y_valid = X[600:1000], y[600:1000]
 X_train_valid, y_train_valid = X[:1000], y[:1000]
@@ -82,58 +84,96 @@ clf_probs = clf.predict_proba(X_test)
 cal_clf_probs = cal_clf.predict_proba(X_test)
 # Plot arrows
 for i in range(clf_probs.shape[0]):
-    plt.arrow(clf_probs[i, 0], clf_probs[i, 1],
-              cal_clf_probs[i, 0] - clf_probs[i, 0],
-              cal_clf_probs[i, 1] - clf_probs[i, 1],
-              color=colors[y_test[i]], head_width=1e-2)
+    plt.arrow(
+        clf_probs[i, 0],
+        clf_probs[i, 1],
+        cal_clf_probs[i, 0] - clf_probs[i, 0],
+        cal_clf_probs[i, 1] - clf_probs[i, 1],
+        color=colors[y_test[i]],
+        head_width=1e-2,
+    )
 
 # Plot perfect predictions, at each vertex
-plt.plot([1.0], [0.0], 'ro', ms=20, label="Class 1")
-plt.plot([0.0], [1.0], 'go', ms=20, label="Class 2")
-plt.plot([0.0], [0.0], 'bo', ms=20, label="Class 3")
+plt.plot([1.0], [0.0], "ro", ms=20, label="Class 1")
+plt.plot([0.0], [1.0], "go", ms=20, label="Class 2")
+plt.plot([0.0], [0.0], "bo", ms=20, label="Class 3")
 
 # Plot boundaries of unit simplex
-plt.plot([0.0, 1.0, 0.0, 0.0], [0.0, 0.0, 1.0, 0.0], 'k', label="Simplex")
+plt.plot([0.0, 1.0, 0.0, 0.0], [0.0, 0.0, 1.0, 0.0], "k", label="Simplex")
 
 # Annotate points 6 points around the simplex, and mid point inside simplex
-plt.annotate(r'($\frac{1}{3}$, $\frac{1}{3}$, $\frac{1}{3}$)',
-             xy=(1.0/3, 1.0/3), xytext=(1.0/3, .23), xycoords='data',
-             arrowprops=dict(facecolor='black', shrink=0.05),
-             horizontalalignment='center', verticalalignment='center')
-plt.plot([1.0/3], [1.0/3], 'ko', ms=5)
-plt.annotate(r'($\frac{1}{2}$, $0$, $\frac{1}{2}$)',
-             xy=(.5, .0), xytext=(.5, .1), xycoords='data',
-             arrowprops=dict(facecolor='black', shrink=0.05),
-             horizontalalignment='center', verticalalignment='center')
-plt.annotate(r'($0$, $\frac{1}{2}$, $\frac{1}{2}$)',
-             xy=(.0, .5), xytext=(.1, .5), xycoords='data',
-             arrowprops=dict(facecolor='black', shrink=0.05),
-             horizontalalignment='center', verticalalignment='center')
-plt.annotate(r'($\frac{1}{2}$, $\frac{1}{2}$, $0$)',
-             xy=(.5, .5), xytext=(.6, .6), xycoords='data',
-             arrowprops=dict(facecolor='black', shrink=0.05),
-             horizontalalignment='center', verticalalignment='center')
-plt.annotate(r'($0$, $0$, $1$)',
-             xy=(0, 0), xytext=(.1, .1), xycoords='data',
-             arrowprops=dict(facecolor='black', shrink=0.05),
-             horizontalalignment='center', verticalalignment='center')
-plt.annotate(r'($1$, $0$, $0$)',
-             xy=(1, 0), xytext=(1, .1), xycoords='data',
-             arrowprops=dict(facecolor='black', shrink=0.05),
-             horizontalalignment='center', verticalalignment='center')
-plt.annotate(r'($0$, $1$, $0$)',
-             xy=(0, 1), xytext=(.1, 1), xycoords='data',
-             arrowprops=dict(facecolor='black', shrink=0.05),
-             horizontalalignment='center', verticalalignment='center')
+plt.annotate(
+    r"($\frac{1}{3}$, $\frac{1}{3}$, $\frac{1}{3}$)",
+    xy=(1.0 / 3, 1.0 / 3),
+    xytext=(1.0 / 3, 0.23),
+    xycoords="data",
+    arrowprops=dict(facecolor="black", shrink=0.05),
+    horizontalalignment="center",
+    verticalalignment="center",
+)
+plt.plot([1.0 / 3], [1.0 / 3], "ko", ms=5)
+plt.annotate(
+    r"($\frac{1}{2}$, $0$, $\frac{1}{2}$)",
+    xy=(0.5, 0.0),
+    xytext=(0.5, 0.1),
+    xycoords="data",
+    arrowprops=dict(facecolor="black", shrink=0.05),
+    horizontalalignment="center",
+    verticalalignment="center",
+)
+plt.annotate(
+    r"($0$, $\frac{1}{2}$, $\frac{1}{2}$)",
+    xy=(0.0, 0.5),
+    xytext=(0.1, 0.5),
+    xycoords="data",
+    arrowprops=dict(facecolor="black", shrink=0.05),
+    horizontalalignment="center",
+    verticalalignment="center",
+)
+plt.annotate(
+    r"($\frac{1}{2}$, $\frac{1}{2}$, $0$)",
+    xy=(0.5, 0.5),
+    xytext=(0.6, 0.6),
+    xycoords="data",
+    arrowprops=dict(facecolor="black", shrink=0.05),
+    horizontalalignment="center",
+    verticalalignment="center",
+)
+plt.annotate(
+    r"($0$, $0$, $1$)",
+    xy=(0, 0),
+    xytext=(0.1, 0.1),
+    xycoords="data",
+    arrowprops=dict(facecolor="black", shrink=0.05),
+    horizontalalignment="center",
+    verticalalignment="center",
+)
+plt.annotate(
+    r"($1$, $0$, $0$)",
+    xy=(1, 0),
+    xytext=(1, 0.1),
+    xycoords="data",
+    arrowprops=dict(facecolor="black", shrink=0.05),
+    horizontalalignment="center",
+    verticalalignment="center",
+)
+plt.annotate(
+    r"($0$, $1$, $0$)",
+    xy=(0, 1),
+    xytext=(0.1, 1),
+    xycoords="data",
+    arrowprops=dict(facecolor="black", shrink=0.05),
+    horizontalalignment="center",
+    verticalalignment="center",
+)
 # Add grid
 plt.grid(False)
 for x in [0.0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0]:
-    plt.plot([0, x], [x, 0], 'k', alpha=0.2)
-    plt.plot([0, 0 + (1-x)/2], [x, x + (1-x)/2], 'k', alpha=0.2)
-    plt.plot([x, x + (1-x)/2], [0, 0 + (1-x)/2], 'k', alpha=0.2)
+    plt.plot([0, x], [x, 0], "k", alpha=0.2)
+    plt.plot([0, 0 + (1 - x) / 2], [x, x + (1 - x) / 2], "k", alpha=0.2)
+    plt.plot([x, x + (1 - x) / 2], [0, 0 + (1 - x) / 2], "k", alpha=0.2)
 
-plt.title("Change of predicted probabilities on test samples "
-          "after sigmoid calibration")
+plt.title("Change of predicted probabilities on test samples after sigmoid calibration")
 plt.xlabel("Probability class 1")
 plt.ylabel("Probability class 2")
 plt.xlim(-0.05, 1.05)
@@ -193,9 +233,12 @@ p = p[p[:, 2] >= 0]
 
 # Use the three class-wise calibrators to compute calibrated probabilities
 calibrated_classifier = cal_clf.calibrated_classifiers_[0]
-prediction = np.vstack([calibrator.predict(this_p)
-                        for calibrator, this_p in
-                        zip(calibrated_classifier.calibrators, p.T)]).T
+prediction = np.vstack(
+    [
+        calibrator.predict(this_p)
+        for calibrator, this_p in zip(calibrated_classifier.calibrators, p.T)
+    ]
+).T
 
 # Re-normalize the calibrated predictions to make sure they stay inside the
 # simplex. This same renormalization step is performed internally by the
@@ -204,18 +247,23 @@ prediction /= prediction.sum(axis=1)[:, None]
 
 # Plot changes in predicted probabilities induced by the calibrators
 for i in range(prediction.shape[0]):
-    plt.arrow(p[i, 0], p[i, 1],
-              prediction[i, 0] - p[i, 0], prediction[i, 1] - p[i, 1],
-              head_width=1e-2, color=colors[np.argmax(p[i])])
+    plt.arrow(
+        p[i, 0],
+        p[i, 1],
+        prediction[i, 0] - p[i, 0],
+        prediction[i, 1] - p[i, 1],
+        head_width=1e-2,
+        color=colors[np.argmax(p[i])],
+    )
 
 # Plot the boundaries of the unit simplex
-plt.plot([0.0, 1.0, 0.0, 0.0], [0.0, 0.0, 1.0, 0.0], 'k', label="Simplex")
+plt.plot([0.0, 1.0, 0.0, 0.0], [0.0, 0.0, 1.0, 0.0], "k", label="Simplex")
 
 plt.grid(False)
 for x in [0.0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0]:
-    plt.plot([0, x], [x, 0], 'k', alpha=0.2)
-    plt.plot([0, 0 + (1-x)/2], [x, x + (1-x)/2], 'k', alpha=0.2)
-    plt.plot([x, x + (1-x)/2], [0, 0 + (1-x)/2], 'k', alpha=0.2)
+    plt.plot([0, x], [x, 0], "k", alpha=0.2)
+    plt.plot([0, 0 + (1 - x) / 2], [x, x + (1 - x) / 2], "k", alpha=0.2)
+    plt.plot([x, x + (1 - x) / 2], [0, 0 + (1 - x) / 2], "k", alpha=0.2)
 
 plt.title("Learned sigmoid calibration map")
 plt.xlabel("Probability class 1")
