@@ -18,8 +18,8 @@ clusters are reassigned during the successive calls to
 partial-fit. This is because the number of patches that they represent
 has become too low, and it is better to choose a random new
 cluster.
+
 """
-print(__doc__)
 
 import time
 
@@ -36,7 +36,7 @@ faces = datasets.fetch_olivetti_faces()
 # #############################################################################
 # Learn the dictionary of images
 
-print('Learning the dictionary... ')
+print("Learning the dictionary... ")
 rng = np.random.RandomState(0)
 kmeans = MiniBatchKMeans(n_clusters=81, random_state=rng, verbose=True)
 patch_size = (20, 20)
@@ -48,8 +48,7 @@ t0 = time.time()
 index = 0
 for _ in range(6):
     for img in faces.images:
-        data = extract_patches_2d(img, patch_size, max_patches=50,
-                                  random_state=rng)
+        data = extract_patches_2d(img, patch_size, max_patches=50, random_state=rng)
         data = np.reshape(data, (len(data), -1))
         buffer.append(data)
         index += 1
@@ -60,25 +59,25 @@ for _ in range(6):
             kmeans.partial_fit(data)
             buffer = []
         if index % 100 == 0:
-            print('Partial fit of %4i out of %i'
-                  % (index, 6 * len(faces.images)))
+            print("Partial fit of %4i out of %i" % (index, 6 * len(faces.images)))
 
 dt = time.time() - t0
-print('done in %.2fs.' % dt)
+print("done in %.2fs." % dt)
 
 # #############################################################################
 # Plot the results
 plt.figure(figsize=(4.2, 4))
 for i, patch in enumerate(kmeans.cluster_centers_):
     plt.subplot(9, 9, i + 1)
-    plt.imshow(patch.reshape(patch_size), cmap=plt.cm.gray,
-               interpolation='nearest')
+    plt.imshow(patch.reshape(patch_size), cmap=plt.cm.gray, interpolation="nearest")
     plt.xticks(())
     plt.yticks(())
 
 
-plt.suptitle('Patches of faces\nTrain time %.1fs on %d patches' %
-             (dt, 8 * len(faces.images)), fontsize=16)
+plt.suptitle(
+    "Patches of faces\nTrain time %.1fs on %d patches" % (dt, 8 * len(faces.images)),
+    fontsize=16,
+)
 plt.subplots_adjust(0.08, 0.02, 0.92, 0.85, 0.08, 0.23)
 
 plt.show()
