@@ -11,13 +11,12 @@ This example compares 2 dimensionality reduction strategies:
 
 Both methods are compared in a regression problem using
 a BayesianRidge as supervised estimator.
+
 """
 
 # Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>
 # License: BSD 3 clause
 
-print(__doc__)
-
 import shutil
 import tempfile
 
@@ -39,13 +38,13 @@ from sklearn.model_selection import KFold
 n_samples = 200
 size = 40  # image size
 roi_size = 15
-snr = 5.
+snr = 5.0
 np.random.seed(0)
 mask = np.ones([size, size], dtype=bool)
 
 coef = np.zeros((size, size))
-coef[0:roi_size, 0:roi_size] = -1.
-coef[-roi_size:, -roi_size:] = 1.
+coef[0:roi_size, 0:roi_size] = -1.0
+coef[-roi_size:, -roi_size:] = 1.0
 
 X = np.random.randn(n_samples, size ** 2)
 for x in X:  # smooth data
@@ -55,7 +54,7 @@ X /= X.std(axis=0)
 
 y = np.dot(X, coef.ravel())
 noise = np.random.randn(y.shape[0])
-noise_coef = (linalg.norm(y, 2) / np.exp(snr / 20.)) / linalg.norm(noise, 2)
+noise_coef = (linalg.norm(y, 2) / np.exp(snr / 20.0)) / linalg.norm(noise, 2)
 y += noise_coef * noise  # add noise
 
 # #############################################################################
@@ -67,11 +66,10 @@ mem = Memory(location=cachedir, verbose=1)
 
 # Ward agglomeration followed by BayesianRidge
 connectivity = grid_to_graph(n_x=size, n_y=size)
-ward = FeatureAgglomeration(n_clusters=10, connectivity=connectivity,
-                            memory=mem)
-clf = Pipeline([('ward', ward), ('ridge', ridge)])
+ward = FeatureAgglomeration(n_clusters=10, connectivity=connectivity, memory=mem)
+clf = Pipeline([("ward", ward), ("ridge", ridge)])
 # Select the optimal number of parcels with grid search
-clf = GridSearchCV(clf, {'ward__n_clusters': [10, 20, 30]}, n_jobs=1, cv=cv)
+clf = GridSearchCV(clf, {"ward__n_clusters": [10, 20, 30]}, n_jobs=1, cv=cv)
 clf.fit(X, y)  # set the best parameters
 coef_ = clf.best_estimator_.steps[-1][1].coef_
 coef_ = clf.best_estimator_.steps[0][1].inverse_transform(coef_)
@@ -80,9 +78,9 @@ coef_agglomeration_ = coef_.reshape(size, size)
 # Anova univariate feature selection followed by BayesianRidge
 f_regression = mem.cache(feature_selection.f_regression)  # caching function
 anova = feature_selection.SelectPercentile(f_regression)
-clf = Pipeline([('anova', anova), ('ridge', ridge)])
+clf = Pipeline([("anova", anova), ("ridge", ridge)])
 # Select the optimal percentage of features with grid search
-clf = GridSearchCV(clf, {'anova__percentile': [5, 10, 20]}, cv=cv)
+clf = GridSearchCV(clf, {"anova__percentile": [5, 10, 20]}, cv=cv)
 clf.fit(X, y)  # set the best parameters
 coef_ = clf.best_estimator_.steps[-1][1].coef_
 coef_ = clf.best_estimator_.steps[0][1].inverse_transform(coef_.reshape(1, -1))
@@ -90,7 +88,7 @@ coef_selection_ = coef_.reshape(size, size)
 
 # #############################################################################
 # Inverse the transformation to plot the results on an image
-plt.close('all')
+plt.close("all")
 plt.figure(figsize=(7.3, 2.7))
 plt.subplot(1, 3, 1)
 plt.imshow(coef, interpolation="nearest", cmap=plt.cm.RdBu_r)
