@@ -10,7 +10,6 @@ feature space analysis". IEEE Transactions on Pattern Analysis and
 Machine Intelligence. 2002. pp. 603-619.
 
 """
-print(__doc__)
 
 import numpy as np
 from sklearn.cluster import MeanShift, estimate_bandwidth
@@ -45,12 +44,18 @@ from itertools import cycle
 plt.figure(1)
 plt.clf()
 
-colors = cycle('bgrcmykbgrcmykbgrcmykbgrcmyk')
+colors = cycle("bgrcmykbgrcmykbgrcmykbgrcmyk")
 for k, col in zip(range(n_clusters_), colors):
     my_members = labels == k
     cluster_center = cluster_centers[k]
-    plt.plot(X[my_members, 0], X[my_members, 1], col + '.')
-    plt.plot(cluster_center[0], cluster_center[1], 'o', markerfacecolor=col,
-             markeredgecolor='k', markersize=14)
-plt.title('Estimated number of clusters: %d' % n_clusters_)
+    plt.plot(X[my_members, 0], X[my_members, 1], col + ".")
+    plt.plot(
+        cluster_center[0],
+        cluster_center[1],
+        "o",
+        markerfacecolor=col,
+        markeredgecolor="k",
+        markersize=14,
+    )
+plt.title("Estimated number of clusters: %d" % n_clusters_)
 plt.show()
