@@ -17,6 +17,7 @@ Some of the clusters learned without connectivity constraints do not
 respect the structure of the swiss roll and extend across different folds of
 the manifolds. On the opposite, when opposing connectivity constraints,
 the clusters form a nice parcellation of the swiss roll.
+
 """
 
 # Authors : Vincent Michel, 2010
@@ -24,8 +25,6 @@ the clusters form a nice parcellation of the swiss roll.
 #           Gael Varoquaux, 2010
 # License: BSD 3 clause
 
-print(__doc__)
-
 import time as time
 import numpy as np
 import matplotlib.pyplot as plt
@@ -39,13 +38,13 @@ n_samples = 1500
 noise = 0.05
 X, _ = make_swiss_roll(n_samples, noise=noise)
 # Make it thinner
-X[:, 1] *= .5
+X[:, 1] *= 0.5
 
 # #############################################################################
 # Compute clustering
 print("Compute unstructured hierarchical clustering...")
 st = time.time()
-ward = AgglomerativeClustering(n_clusters=6, linkage='ward').fit(X)
+ward = AgglomerativeClustering(n_clusters=6, linkage="ward").fit(X)
 elapsed_time = time.time() - st
 label = ward.labels_
 print("Elapsed time: %.2fs" % elapsed_time)
@@ -57,23 +56,30 @@ fig = plt.figure()
 ax = p3.Axes3D(fig)
 ax.view_init(7, -80)
 for l in np.unique(label):
-    ax.scatter(X[label == l, 0], X[label == l, 1], X[label == l, 2],
-               color=plt.cm.jet(float(l) / np.max(label + 1)),
-               s=20, edgecolor='k')
-plt.title('Without connectivity constraints (time %.2fs)' % elapsed_time)
+    ax.scatter(
+        X[label == l, 0],
+        X[label == l, 1],
+        X[label == l, 2],
+        color=plt.cm.jet(float(l) / np.max(label + 1)),
+        s=20,
+        edgecolor="k",
+    )
+plt.title("Without connectivity constraints (time %.2fs)" % elapsed_time)
 
 
 # #############################################################################
 # Define the structure A of the data. Here a 10 nearest neighbors
 from sklearn.neighbors import kneighbors_graph
+
 connectivity = kneighbors_graph(X, n_neighbors=10, include_self=False)
 
 # #############################################################################
 # Compute clustering
 print("Compute structured hierarchical clustering...")
 st = time.time()
-ward = AgglomerativeClustering(n_clusters=6, connectivity=connectivity,
-                               linkage='ward').fit(X)
+ward = AgglomerativeClustering(
+    n_clusters=6, connectivity=connectivity, linkage="ward"
+).fit(X)
 elapsed_time = time.time() - st
 label = ward.labels_
 print("Elapsed time: %.2fs" % elapsed_time)
@@ -85,9 +91,14 @@ fig = plt.figure()
 ax = p3.Axes3D(fig)
 ax.view_init(7, -80)
 for l in np.unique(label):
-    ax.scatter(X[label == l, 0], X[label == l, 1], X[label == l, 2],
-               color=plt.cm.jet(float(l) / np.max(label + 1)),
-               s=20, edgecolor='k')
-plt.title('With connectivity constraints (time %.2fs)' % elapsed_time)
+    ax.scatter(
+        X[label == l, 0],
+        X[label == l, 1],
+        X[label == l, 2],
+        color=plt.cm.jet(float(l) / np.max(label + 1)),
+        s=20,
+        edgecolor="k",
+    )
+plt.title("With connectivity constraints (time %.2fs)" % elapsed_time)
 
 plt.show()
