@@ -41,14 +41,18 @@ approaches outperform cross-validation, which is significantly most
 computationally costly.
 
 """
-print(__doc__)
 
 import numpy as np
 import matplotlib.pyplot as plt
 from scipy import linalg
 
-from sklearn.covariance import LedoitWolf, OAS, ShrunkCovariance, \
-    log_likelihood, empirical_covariance
+from sklearn.covariance import (
+    LedoitWolf,
+    OAS,
+    ShrunkCovariance,
+    log_likelihood,
+    empirical_covariance,
+)
 from sklearn.model_selection import GridSearchCV
 
 
@@ -69,8 +73,9 @@ X_test = np.dot(base_X_test, coloring_matrix)
 
 # spanning a range of possible shrinkage coefficient values
 shrinkages = np.logspace(-2, 0, 30)
-negative_logliks = [-ShrunkCovariance(shrinkage=s).fit(X_train).score(X_test)
-                    for s in shrinkages]
+negative_logliks = [
+    -ShrunkCovariance(shrinkage=s).fit(X_train).score(X_test) for s in shrinkages
+]
 
 # under the ground-truth model, which we would not have access to in real
 # settings
@@ -82,7 +87,7 @@ loglik_real = -log_likelihood(emp_cov, linalg.inv(real_cov))
 # Compare different approaches to setting the parameter
 
 # GridSearch for an optimal shrinkage coefficient
-tuned_parameters = [{'shrinkage': shrinkages}]
+tuned_parameters = [{"shrinkage": shrinkages}]
 cv = GridSearchCV(ShrunkCovariance(), tuned_parameters)
 cv.fit(X_train)
 
@@ -98,31 +103,42 @@ loglik_oa = oa.fit(X_train).score(X_test)
 # Plot results
 fig = plt.figure()
 plt.title("Regularized covariance: likelihood and shrinkage coefficient")
-plt.xlabel('Regularization parameter: shrinkage coefficient')
-plt.ylabel('Error: negative log-likelihood on test data')
+plt.xlabel("Regularization parameter: shrinkage coefficient")
+plt.ylabel("Error: negative log-likelihood on test data")
 # range shrinkage curve
 plt.loglog(shrinkages, negative_logliks, label="Negative log-likelihood")
 
-plt.plot(plt.xlim(), 2 * [loglik_real], '--r',
-         label="Real covariance likelihood")
+plt.plot(plt.xlim(), 2 * [loglik_real], "--r", label="Real covariance likelihood")
 
 # adjust view
 lik_max = np.amax(negative_logliks)
 lik_min = np.amin(negative_logliks)
-ymin = lik_min - 6. * np.log((plt.ylim()[1] - plt.ylim()[0]))
-ymax = lik_max + 10. * np.log(lik_max - lik_min)
+ymin = lik_min - 6.0 * np.log((plt.ylim()[1] - plt.ylim()[0]))
+ymax = lik_max + 10.0 * np.log(lik_max - lik_min)
 xmin = shrinkages[0]
 xmax = shrinkages[-1]
 # LW likelihood
-plt.vlines(lw.shrinkage_, ymin, -loglik_lw, color='magenta',
-           linewidth=3, label='Ledoit-Wolf estimate')
+plt.vlines(
+    lw.shrinkage_,
+    ymin,
+    -loglik_lw,
+    color="magenta",
+    linewidth=3,
+    label="Ledoit-Wolf estimate",
+)
 # OAS likelihood
-plt.vlines(oa.shrinkage_, ymin, -loglik_oa, color='purple',
-           linewidth=3, label='OAS estimate')
+plt.vlines(
+    oa.shrinkage_, ymin, -loglik_oa, color="purple", linewidth=3, label="OAS estimate"
+)
 # best CV estimator likelihood
-plt.vlines(cv.best_estimator_.shrinkage, ymin,
-           -cv.best_estimator_.score(X_test), color='cyan',
-           linewidth=3, label='Cross-validation best estimate')
+plt.vlines(
+    cv.best_estimator_.shrinkage,
+    ymin,
+    -cv.best_estimator_.score(X_test),
+    color="cyan",
+    linewidth=3,
+    label="Cross-validation best estimate",
+)
 
 plt.ylim(ymin, ymax)
 plt.xlim(xmin, xmax)
