@@ -47,8 +47,9 @@ The alpha parameter of the GraphicalLasso setting the sparsity of the model is
 set by internal cross-validation in the GraphicalLassoCV. As can be
 seen on figure 2, the grid to compute the cross-validation score is
 iteratively refined in the neighborhood of the maximum.
+
 """
-print(__doc__)
+
 # author: Gael Varoquaux <gael.varoquaux@inria.fr>
 # License: BSD 3 clause
 # Copyright: INRIA
@@ -65,10 +66,9 @@ n_samples = 60
 n_features = 20
 
 prng = np.random.RandomState(1)
-prec = make_sparse_spd_matrix(n_features, alpha=.98,
-                              smallest_coef=.4,
-                              largest_coef=.7,
-                              random_state=prng)
+prec = make_sparse_spd_matrix(
+    n_features, alpha=0.98, smallest_coef=0.4, largest_coef=0.7, random_state=prng
+)
 cov = linalg.inv(prec)
 d = np.sqrt(np.diag(cov))
 cov /= d
@@ -97,42 +97,55 @@ plt.figure(figsize=(10, 6))
 plt.subplots_adjust(left=0.02, right=0.98)
 
 # plot the covariances
-covs = [('Empirical', emp_cov), ('Ledoit-Wolf', lw_cov_),
-        ('GraphicalLassoCV', cov_), ('True', cov)]
+covs = [
+    ("Empirical", emp_cov),
+    ("Ledoit-Wolf", lw_cov_),
+    ("GraphicalLassoCV", cov_),
+    ("True", cov),
+]
 vmax = cov_.max()
 for i, (name, this_cov) in enumerate(covs):
     plt.subplot(2, 4, i + 1)
-    plt.imshow(this_cov, interpolation='nearest', vmin=-vmax, vmax=vmax,
-               cmap=plt.cm.RdBu_r)
+    plt.imshow(
+        this_cov, interpolation="nearest", vmin=-vmax, vmax=vmax, cmap=plt.cm.RdBu_r
+    )
     plt.xticks(())
     plt.yticks(())
-    plt.title('%s covariance' % name)
+    plt.title("%s covariance" % name)
 
 
 # plot the precisions
-precs = [('Empirical', linalg.inv(emp_cov)), ('Ledoit-Wolf', lw_prec_),
-         ('GraphicalLasso', prec_), ('True', prec)]
-vmax = .9 * prec_.max()
+precs = [
+    ("Empirical", linalg.inv(emp_cov)),
+    ("Ledoit-Wolf", lw_prec_),
+    ("GraphicalLasso", prec_),
+    ("True", prec),
+]
+vmax = 0.9 * prec_.max()
 for i, (name, this_prec) in enumerate(precs):
     ax = plt.subplot(2, 4, i + 5)
-    plt.imshow(np.ma.masked_equal(this_prec, 0),
-               interpolation='nearest', vmin=-vmax, vmax=vmax,
-               cmap=plt.cm.RdBu_r)
+    plt.imshow(
+        np.ma.masked_equal(this_prec, 0),
+        interpolation="nearest",
+        vmin=-vmax,
+        vmax=vmax,
+        cmap=plt.cm.RdBu_r,
+    )
     plt.xticks(())
     plt.yticks(())
-    plt.title('%s precision' % name)
-    if hasattr(ax, 'set_facecolor'):
-        ax.set_facecolor('.7')
+    plt.title("%s precision" % name)
+    if hasattr(ax, "set_facecolor"):
+        ax.set_facecolor(".7")
     else:
-        ax.set_axis_bgcolor('.7')
+        ax.set_axis_bgcolor(".7")
 
 # plot the model selection metric
 plt.figure(figsize=(4, 3))
-plt.axes([.2, .15, .75, .7])
-plt.plot(model.cv_results_["alphas"], model.cv_results_["mean_score"], 'o-')
-plt.axvline(model.alpha_, color='.5')
-plt.title('Model selection')
-plt.ylabel('Cross-validation score')
-plt.xlabel('alpha')
+plt.axes([0.2, 0.15, 0.75, 0.7])
+plt.plot(model.cv_results_["alphas"], model.cv_results_["mean_score"], "o-")
+plt.axvline(model.alpha_, color=".5")
+plt.title("Model selection")
+plt.ylabel("Cross-validation score")
+plt.xlabel("alpha")
 
 plt.show()
