@@ -1,6 +1,4 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 """
 =========================================================
 The Iris Dataset
@@ -15,9 +13,8 @@ Sepal Length, Sepal Width, Petal Length and Petal Width.
 The below plot uses the first two features.
 See `here <https://en.wikipedia.org/wiki/Iris_flower_data_set>`_ for more
 information on this dataset.
-"""
-print(__doc__)
 
+"""
 
 # Code source: Gaël Varoquaux
 # Modified for documentation by Jaques Grobler
@@ -33,17 +30,16 @@ iris = datasets.load_iris()
 X = iris.data[:, :2]  # we only take the first two features.
 y = iris.target
 
-x_min, x_max = X[:, 0].min() - .5, X[:, 0].max() + .5
-y_min, y_max = X[:, 1].min() - .5, X[:, 1].max() + .5
+x_min, x_max = X[:, 0].min() - 0.5, X[:, 0].max() + 0.5
+y_min, y_max = X[:, 1].min() - 0.5, X[:, 1].max() + 0.5
 
 plt.figure(2, figsize=(8, 6))
 plt.clf()
 
 # Plot the training points
-plt.scatter(X[:, 0], X[:, 1], c=y, cmap=plt.cm.Set1,
-            edgecolor='k')
-plt.xlabel('Sepal length')
-plt.ylabel('Sepal width')
+plt.scatter(X[:, 0], X[:, 1], c=y, cmap=plt.cm.Set1, edgecolor="k")
+plt.xlabel("Sepal length")
+plt.ylabel("Sepal width")
 
 plt.xlim(x_min, x_max)
 plt.ylim(y_min, y_max)
@@ -55,8 +51,15 @@ plt.yticks(())
 fig = plt.figure(1, figsize=(8, 6))
 ax = Axes3D(fig, elev=-150, azim=110)
 X_reduced = PCA(n_components=3).fit_transform(iris.data)
-ax.scatter(X_reduced[:, 0], X_reduced[:, 1], X_reduced[:, 2], c=y,
-           cmap=plt.cm.Set1, edgecolor='k', s=40)
+ax.scatter(
+    X_reduced[:, 0],
+    X_reduced[:, 1],
+    X_reduced[:, 2],
+    c=y,
+    cmap=plt.cm.Set1,
+    edgecolor="k",
+    s=40,
+)
 ax.set_title("First three PCA directions")
 ax.set_xlabel("1st eigenvector")
 ax.w_xaxis.set_ticklabels([])
