@@ -22,8 +22,9 @@ can mitigate those limitations.
 
    [1] L. Breiman, "Random Forests", Machine Learning, 45(1), 5-32,
        2001. https://doi.org/10.1023/A:1010933404324
+
 """
-print(__doc__)
+
 import matplotlib.pyplot as plt
 import numpy as np
 
@@ -52,30 +53,32 @@ from sklearn.preprocessing import OneHotEncoder
 #   values).
 X, y = fetch_openml("titanic", version=1, as_frame=True, return_X_y=True)
 rng = np.random.RandomState(seed=42)
-X['random_cat'] = rng.randint(3, size=X.shape[0])
-X['random_num'] = rng.randn(X.shape[0])
+X["random_cat"] = rng.randint(3, size=X.shape[0])
+X["random_num"] = rng.randn(X.shape[0])
 
-categorical_columns = ['pclass', 'sex', 'embarked', 'random_cat']
-numerical_columns = ['age', 'sibsp', 'parch', 'fare', 'random_num']
+categorical_columns = ["pclass", "sex", "embarked", "random_cat"]
+numerical_columns = ["age", "sibsp", "parch", "fare", "random_num"]
 
 X = X[categorical_columns + numerical_columns]
 
-X_train, X_test, y_train, y_test = train_test_split(
-    X, y, stratify=y, random_state=42)
+X_train, X_test, y_train, y_test = train_test_split(X, y, stratify=y, random_state=42)
 
-categorical_encoder = OneHotEncoder(handle_unknown='ignore')
-numerical_pipe = Pipeline([
-    ('imputer', SimpleImputer(strategy='mean'))
-])
+categorical_encoder = OneHotEncoder(handle_unknown="ignore")
+numerical_pipe = Pipeline([("imputer", SimpleImputer(strategy="mean"))])
 
 preprocessing = ColumnTransformer(
-    [('cat', categorical_encoder, categorical_columns),
-     ('num', numerical_pipe, numerical_columns)])
+    [
+        ("cat", categorical_encoder, categorical_columns),
+        ("num", numerical_pipe, numerical_columns),
+    ]
+)
 
-rf = Pipeline([
-    ('preprocess', preprocessing),
-    ('classifier', RandomForestClassifier(random_state=42))
-])
+rf = Pipeline(
+    [
+        ("preprocess", preprocessing),
+        ("classifier", RandomForestClassifier(random_state=42)),
+    ]
+)
 rf.fit(X_train, y_train)
 
 # %%
@@ -118,13 +121,11 @@ print("RF test accuracy: %0.3f" % rf.score(X_test, y_test))
 #   therefore do not reflect the ability of feature to be useful to make
 #   predictions that generalize to the test set (when the model has enough
 #   capacity).
-ohe = (rf.named_steps['preprocess']
-         .named_transformers_['cat'])
+ohe = rf.named_steps["preprocess"].named_transformers_["cat"]
 feature_names = ohe.get_feature_names_out(categorical_columns)
 feature_names = np.r_[feature_names, numerical_columns]
 
-tree_feature_importances = (
-    rf.named_steps['classifier'].feature_importances_)
+tree_feature_importances = rf.named_steps["classifier"].feature_importances_
 sorted_idx = tree_feature_importances.argsort()
 
 y_ticks = np.arange(0, len(feature_names))
@@ -144,13 +145,15 @@ plt.show()
 #
 # Also note that both random features have very low importances (close to 0) as
 # expected.
-result = permutation_importance(rf, X_test, y_test, n_repeats=10,
-                                random_state=42, n_jobs=2)
+result = permutation_importance(
+    rf, X_test, y_test, n_repeats=10, random_state=42, n_jobs=2
+)
 sorted_idx = result.importances_mean.argsort()
 
 fig, ax = plt.subplots()
-ax.boxplot(result.importances[sorted_idx].T,
-           vert=False, labels=X_test.columns[sorted_idx])
+ax.boxplot(
+    result.importances[sorted_idx].T, vert=False, labels=X_test.columns[sorted_idx]
+)
 ax.set_title("Permutation Importances (test set)")
 fig.tight_layout()
 plt.show()
@@ -162,13 +165,15 @@ plt.show()
 # plots is a confirmation that the RF model has enough capacity to use that
 # random numerical feature to overfit. You can further confirm this by
 # re-running this example with constrained RF with min_samples_leaf=10.
-result = permutation_importance(rf, X_train, y_train, n_repeats=10,
-                                random_state=42, n_jobs=2)
+result = permutation_importance(
+    rf, X_train, y_train, n_repeats=10, random_state=42, n_jobs=2
+)
 sorted_idx = result.importances_mean.argsort()
 
 fig, ax = plt.subplots()
-ax.boxplot(result.importances[sorted_idx].T,
-           vert=False, labels=X_train.columns[sorted_idx])
+ax.boxplot(
+    result.importances[sorted_idx].T, vert=False, labels=X_train.columns[sorted_idx]
+)
 ax.set_title("Permutation Importances (train set)")
 fig.tight_layout()
 plt.show()
