@@ -21,8 +21,8 @@ for one dimensional regression using polynomial feature expansion.
 Note the uncertainty starts going up on the right side of the plot.
 This is because these test samples are outside of the range of the training
 samples.
+
 """
-print(__doc__)
 
 import numpy as np
 import matplotlib.pyplot as plt
@@ -39,15 +39,15 @@ n_samples, n_features = 100, 100
 # Create Gaussian data
 X = np.random.randn(n_samples, n_features)
 # Create weights with a precision lambda_ of 4.
-lambda_ = 4.
+lambda_ = 4.0
 w = np.zeros(n_features)
 # Only keep 10 weights of interest
 relevant_features = np.random.randint(0, n_features, 10)
 for i in relevant_features:
-    w[i] = stats.norm.rvs(loc=0, scale=1. / np.sqrt(lambda_))
+    w[i] = stats.norm.rvs(loc=0, scale=1.0 / np.sqrt(lambda_))
 # Create noise with a precision alpha of 50.
-alpha_ = 50.
-noise = stats.norm.rvs(loc=0, scale=1. / np.sqrt(alpha_), size=n_samples)
+alpha_ = 50.0
+noise = stats.norm.rvs(loc=0, scale=1.0 / np.sqrt(alpha_), size=n_samples)
 # Create the target
 y = np.dot(X, w) + noise
 
@@ -64,27 +64,32 @@ ols.fit(X, y)
 # weights, and predictions with standard deviations
 plt.figure(figsize=(6, 5))
 plt.title("Weights of the model")
-plt.plot(clf.coef_, color='darkblue', linestyle='-', linewidth=2,
-         label="ARD estimate")
-plt.plot(ols.coef_, color='yellowgreen', linestyle=':', linewidth=2,
-         label="OLS estimate")
-plt.plot(w, color='orange', linestyle='-', linewidth=2, label="Ground truth")
+plt.plot(clf.coef_, color="darkblue", linestyle="-", linewidth=2, label="ARD estimate")
+plt.plot(
+    ols.coef_, color="yellowgreen", linestyle=":", linewidth=2, label="OLS estimate"
+)
+plt.plot(w, color="orange", linestyle="-", linewidth=2, label="Ground truth")
 plt.xlabel("Features")
 plt.ylabel("Values of the weights")
 plt.legend(loc=1)
 
 plt.figure(figsize=(6, 5))
 plt.title("Histogram of the weights")
-plt.hist(clf.coef_, bins=n_features, color='navy', log=True)
-plt.scatter(clf.coef_[relevant_features], 5 * np.ones(len(relevant_features)),
-            color='gold', marker='o', label="Relevant features")
+plt.hist(clf.coef_, bins=n_features, color="navy", log=True)
+plt.scatter(
+    clf.coef_[relevant_features],
+    np.full(len(relevant_features), 5.0),
+    color="gold",
+    marker="o",
+    label="Relevant features",
+)
 plt.ylabel("Features")
 plt.xlabel("Values of the weights")
 plt.legend(loc=1)
 
 plt.figure(figsize=(6, 5))
 plt.title("Marginal log-likelihood")
-plt.plot(clf.scores_, color='navy', linewidth=2)
+plt.plot(clf.scores_, color="navy", linewidth=2)
 plt.ylabel("Score")
 plt.xlabel("Iterations")
 
@@ -106,10 +111,8 @@ X_plot = np.linspace(0, 11, 25)
 y_plot = f(X_plot, noise_amount=0)
 y_mean, y_std = clf_poly.predict(np.vander(X_plot, degree), return_std=True)
 plt.figure(figsize=(6, 5))
-plt.errorbar(X_plot, y_mean, y_std, color='navy',
-             label="Polynomial ARD", linewidth=2)
-plt.plot(X_plot, y_plot, color='gold', linewidth=2,
-         label="Ground Truth")
+plt.errorbar(X_plot, y_mean, y_std, color="navy", label="Polynomial ARD", linewidth=2)
+plt.plot(X_plot, y_plot, color="gold", linewidth=2, label="Ground Truth")
 plt.ylabel("Output y")
 plt.xlabel("Feature X")
 plt.legend(loc="lower left")
