@@ -6,8 +6,9 @@ Plot multinomial and One-vs-Rest Logistic Regression
 Plot decision surface of multinomial and One-vs-Rest Logistic Regression.
 The hyperplanes corresponding to the three One-vs-Rest (OVR) classifiers
 are represented by the dashed lines.
+
 """
-print(__doc__)
+
 # Authors: Tom Dupre la Tour <tom.dupre-la-tour@m4x.org>
 # License: BSD 3 clause
 
@@ -22,19 +23,19 @@ X, y = make_blobs(n_samples=1000, centers=centers, random_state=40)
 transformation = [[0.4, 0.2], [-0.4, 1.2]]
 X = np.dot(X, transformation)
 
-for multi_class in ('multinomial', 'ovr'):
-    clf = LogisticRegression(solver='sag', max_iter=100, random_state=42,
-                             multi_class=multi_class).fit(X, y)
+for multi_class in ("multinomial", "ovr"):
+    clf = LogisticRegression(
+        solver="sag", max_iter=100, random_state=42, multi_class=multi_class
+    ).fit(X, y)
 
     # print the training scores
     print("training score : %.3f (%s)" % (clf.score(X, y), multi_class))
 
     # create a mesh to plot in
-    h = .02  # step size in the mesh
+    h = 0.02  # step size in the mesh
     x_min, x_max = X[:, 0].min() - 1, X[:, 0].max() + 1
     y_min, y_max = X[:, 1].min() - 1, X[:, 1].max() + 1
-    xx, yy = np.meshgrid(np.arange(x_min, x_max, h),
-                         np.arange(y_min, y_max, h))
+    xx, yy = np.meshgrid(np.arange(x_min, x_max, h), np.arange(y_min, y_max, h))
 
     # Plot the decision boundary. For that, we will assign a color to each
     # point in the mesh [x_min, x_max]x[y_min, y_max].
@@ -44,14 +45,15 @@ for multi_class in ('multinomial', 'ovr'):
     plt.figure()
     plt.contourf(xx, yy, Z, cmap=plt.cm.Paired)
     plt.title("Decision surface of LogisticRegression (%s)" % multi_class)
-    plt.axis('tight')
+    plt.axis("tight")
 
     # Plot also the training points
     colors = "bry"
     for i, color in zip(clf.classes_, colors):
         idx = np.where(y == i)
-        plt.scatter(X[idx, 0], X[idx, 1], c=color, cmap=plt.cm.Paired,
-                    edgecolor='black', s=20)
+        plt.scatter(
+            X[idx, 0], X[idx, 1], c=color, cmap=plt.cm.Paired, edgecolor="black", s=20
+        )
 
     # Plot the three one-against-all classifiers
     xmin, xmax = plt.xlim()
@@ -62,8 +64,8 @@ for multi_class in ('multinomial', 'ovr'):
     def plot_hyperplane(c, color):
         def line(x0):
             return (-(x0 * coef[c, 0]) - intercept[c]) / coef[c, 1]
-        plt.plot([xmin, xmax], [line(xmin), line(xmax)],
-                 ls="--", color=color)
+
+        plt.plot([xmin, xmax], [line(xmin), line(xmax)], ls="--", color=color)
 
     for i, color in zip(clf.classes_, colors):
         plot_hyperplane(i, color)
