@@ -29,12 +29,12 @@ SVR scales better. With regard to prediction time, SVR is faster than
 KRR for all sizes of the training set because of the learned sparse
 solution. Note that the degree of sparsity and thus the prediction time depends
 on the parameters epsilon and C of the SVR.
+
 """
 
 # Authors: Jan Hendrik Metzen <jhm@informatik.uni-bremen.de>
 # License: BSD 3 clause
 
-
 import time
 
 import numpy as np
@@ -60,25 +60,25 @@ X_plot = np.linspace(0, 5, 100000)[:, None]
 # #############################################################################
 # Fit regression model
 train_size = 100
-svr = GridSearchCV(SVR(kernel='rbf', gamma=0.1),
-                   param_grid={"C": [1e0, 1e1, 1e2, 1e3],
-                               "gamma": np.logspace(-2, 2, 5)})
+svr = GridSearchCV(
+    SVR(kernel="rbf", gamma=0.1),
+    param_grid={"C": [1e0, 1e1, 1e2, 1e3], "gamma": np.logspace(-2, 2, 5)},
+)
 
-kr = GridSearchCV(KernelRidge(kernel='rbf', gamma=0.1),
-                  param_grid={"alpha": [1e0, 0.1, 1e-2, 1e-3],
-                              "gamma": np.logspace(-2, 2, 5)})
+kr = GridSearchCV(
+    KernelRidge(kernel="rbf", gamma=0.1),
+    param_grid={"alpha": [1e0, 0.1, 1e-2, 1e-3], "gamma": np.logspace(-2, 2, 5)},
+)
 
 t0 = time.time()
 svr.fit(X[:train_size], y[:train_size])
 svr_fit = time.time() - t0
-print("SVR complexity and bandwidth selected and model fitted in %.3f s"
-      % svr_fit)
+print("SVR complexity and bandwidth selected and model fitted in %.3f s" % svr_fit)
 
 t0 = time.time()
 kr.fit(X[:train_size], y[:train_size])
 kr_fit = time.time() - t0
-print("KRR complexity and bandwidth selected and model fitted in %.3f s"
-      % kr_fit)
+print("KRR complexity and bandwidth selected and model fitted in %.3f s" % kr_fit)
 
 sv_ratio = svr.best_estimator_.support_.shape[0] / train_size
 print("Support vector ratio: %.3f" % sv_ratio)
@@ -86,30 +86,39 @@ print("Support vector ratio: %.3f" % sv_ratio)
 t0 = time.time()
 y_svr = svr.predict(X_plot)
 svr_predict = time.time() - t0
-print("SVR prediction for %d inputs in %.3f s"
-      % (X_plot.shape[0], svr_predict))
+print("SVR prediction for %d inputs in %.3f s" % (X_plot.shape[0], svr_predict))
 
 t0 = time.time()
 y_kr = kr.predict(X_plot)
 kr_predict = time.time() - t0
-print("KRR prediction for %d inputs in %.3f s"
-      % (X_plot.shape[0], kr_predict))
+print("KRR prediction for %d inputs in %.3f s" % (X_plot.shape[0], kr_predict))
 
 
 # #############################################################################
 # Look at the results
 sv_ind = svr.best_estimator_.support_
-plt.scatter(X[sv_ind], y[sv_ind], c='r', s=50, label='SVR support vectors',
-            zorder=2, edgecolors=(0, 0, 0))
-plt.scatter(X[:100], y[:100], c='k', label='data', zorder=1,
-            edgecolors=(0, 0, 0))
-plt.plot(X_plot, y_svr, c='r',
-         label='SVR (fit: %.3fs, predict: %.3fs)' % (svr_fit, svr_predict))
-plt.plot(X_plot, y_kr, c='g',
-         label='KRR (fit: %.3fs, predict: %.3fs)' % (kr_fit, kr_predict))
-plt.xlabel('data')
-plt.ylabel('target')
-plt.title('SVR versus Kernel Ridge')
+plt.scatter(
+    X[sv_ind],
+    y[sv_ind],
+    c="r",
+    s=50,
+    label="SVR support vectors",
+    zorder=2,
+    edgecolors=(0, 0, 0),
+)
+plt.scatter(X[:100], y[:100], c="k", label="data", zorder=1, edgecolors=(0, 0, 0))
+plt.plot(
+    X_plot,
+    y_svr,
+    c="r",
+    label="SVR (fit: %.3fs, predict: %.3fs)" % (svr_fit, svr_predict),
+)
+plt.plot(
+    X_plot, y_kr, c="g", label="KRR (fit: %.3fs, predict: %.3fs)" % (kr_fit, kr_predict)
+)
+plt.xlabel("data")
+plt.ylabel("target")
+plt.title("SVR versus Kernel Ridge")
 plt.legend()
 
 # Visualize training and prediction time
@@ -120,9 +129,10 @@ X = 5 * rng.rand(10000, 1)
 y = np.sin(X).ravel()
 y[::5] += 3 * (0.5 - rng.rand(X.shape[0] // 5))
 sizes = np.logspace(1, 4, 7).astype(int)
-for name, estimator in {"KRR": KernelRidge(kernel='rbf', alpha=0.1,
-                                           gamma=10),
-                        "SVR": SVR(kernel='rbf', C=1e1, gamma=10)}.items():
+for name, estimator in {
+    "KRR": KernelRidge(kernel="rbf", alpha=0.1, gamma=10),
+    "SVR": SVR(kernel="rbf", C=1e1, gamma=10),
+}.items():
     train_time = []
     test_time = []
     for train_test_size in sizes:
@@ -134,37 +144,55 @@ for name, estimator in {"KRR": KernelRidge(kernel='rbf', alpha=0.1,
         estimator.predict(X_plot[:1000])
         test_time.append(time.time() - t0)
 
-    plt.plot(sizes, train_time, 'o-', color="r" if name == "SVR" else "g",
-             label="%s (train)" % name)
-    plt.plot(sizes, test_time, 'o--', color="r" if name == "SVR" else "g",
-             label="%s (test)" % name)
+    plt.plot(
+        sizes,
+        train_time,
+        "o-",
+        color="r" if name == "SVR" else "g",
+        label="%s (train)" % name,
+    )
+    plt.plot(
+        sizes,
+        test_time,
+        "o--",
+        color="r" if name == "SVR" else "g",
+        label="%s (test)" % name,
+    )
 
 plt.xscale("log")
 plt.yscale("log")
 plt.xlabel("Train size")
 plt.ylabel("Time (seconds)")
-plt.title('Execution Time')
+plt.title("Execution Time")
 plt.legend(loc="best")
 
 # Visualize learning curves
 plt.figure()
 
-svr = SVR(kernel='rbf', C=1e1, gamma=0.1)
-kr = KernelRidge(kernel='rbf', alpha=0.1, gamma=0.1)
-train_sizes, train_scores_svr, test_scores_svr = \
-    learning_curve(svr, X[:100], y[:100], train_sizes=np.linspace(0.1, 1, 10),
-                   scoring="neg_mean_squared_error", cv=10)
-train_sizes_abs, train_scores_kr, test_scores_kr = \
-    learning_curve(kr, X[:100], y[:100], train_sizes=np.linspace(0.1, 1, 10),
-                   scoring="neg_mean_squared_error", cv=10)
+svr = SVR(kernel="rbf", C=1e1, gamma=0.1)
+kr = KernelRidge(kernel="rbf", alpha=0.1, gamma=0.1)
+train_sizes, train_scores_svr, test_scores_svr = learning_curve(
+    svr,
+    X[:100],
+    y[:100],
+    train_sizes=np.linspace(0.1, 1, 10),
+    scoring="neg_mean_squared_error",
+    cv=10,
+)
+train_sizes_abs, train_scores_kr, test_scores_kr = learning_curve(
+    kr,
+    X[:100],
+    y[:100],
+    train_sizes=np.linspace(0.1, 1, 10),
+    scoring="neg_mean_squared_error",
+    cv=10,
+)
 
-plt.plot(train_sizes, -test_scores_svr.mean(1), 'o-', color="r",
-         label="SVR")
-plt.plot(train_sizes, -test_scores_kr.mean(1), 'o-', color="g",
-         label="KRR")
+plt.plot(train_sizes, -test_scores_svr.mean(1), "o-", color="r", label="SVR")
+plt.plot(train_sizes, -test_scores_kr.mean(1), "o-", color="g", label="KRR")
 plt.xlabel("Train size")
 plt.ylabel("Mean Squared Error")
-plt.title('Learning curves')
+plt.title("Learning curves")
 plt.legend(loc="best")
 
 plt.show()
