@@ -5,8 +5,8 @@ Nearest Centroid Classification
 
 Sample usage of Nearest Centroid classification.
 It will plot the decision boundaries for each class.
+
 """
-print(__doc__)
 
 import numpy as np
 import matplotlib.pyplot as plt
@@ -23,13 +23,13 @@ iris = datasets.load_iris()
 X = iris.data[:, :2]
 y = iris.target
 
-h = .02  # step size in the mesh
+h = 0.02  # step size in the mesh
 
 # Create color maps
-cmap_light = ListedColormap(['orange', 'cyan', 'cornflowerblue'])
-cmap_bold = ListedColormap(['darkorange', 'c', 'darkblue'])
+cmap_light = ListedColormap(["orange", "cyan", "cornflowerblue"])
+cmap_bold = ListedColormap(["darkorange", "c", "darkblue"])
 
-for shrinkage in [None, .2]:
+for shrinkage in [None, 0.2]:
     # we create an instance of Neighbours Classifier and fit the data.
     clf = NearestCentroid(shrink_threshold=shrinkage)
     clf.fit(X, y)
@@ -39,8 +39,7 @@ for shrinkage in [None, .2]:
     # point in the mesh [x_min, x_max]x[y_min, y_max].
     x_min, x_max = X[:, 0].min() - 1, X[:, 0].max() + 1
     y_min, y_max = X[:, 1].min() - 1, X[:, 1].max() + 1
-    xx, yy = np.meshgrid(np.arange(x_min, x_max, h),
-                         np.arange(y_min, y_max, h))
+    xx, yy = np.meshgrid(np.arange(x_min, x_max, h), np.arange(y_min, y_max, h))
     Z = clf.predict(np.c_[xx.ravel(), yy.ravel()])
 
     # Put the result into a color plot
@@ -49,10 +48,8 @@ for shrinkage in [None, .2]:
     plt.pcolormesh(xx, yy, Z, cmap=cmap_light)
 
     # Plot also the training points
-    plt.scatter(X[:, 0], X[:, 1], c=y, cmap=cmap_bold,
-                edgecolor='k', s=20)
-    plt.title("3-Class classification (shrink_threshold=%r)"
-              % shrinkage)
-    plt.axis('tight')
+    plt.scatter(X[:, 0], X[:, 1], c=y, cmap=cmap_bold, edgecolor="k", s=20)
+    plt.title("3-Class classification (shrink_threshold=%r)" % shrinkage)
+    plt.axis("tight")
 
 plt.show()
