@@ -8,7 +8,6 @@ using a k-Nearest Neighbor and the interpolation of the
 target using both barycenter and constant weights.
 
 """
-print(__doc__)
 
 # Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #         Fabian Pedregosa <fabian.pedregosa@inria.fr>
@@ -34,17 +33,16 @@ y[::5] += 1 * (0.5 - np.random.rand(8))
 # Fit regression model
 n_neighbors = 5
 
-for i, weights in enumerate(['uniform', 'distance']):
+for i, weights in enumerate(["uniform", "distance"]):
     knn = neighbors.KNeighborsRegressor(n_neighbors, weights=weights)
     y_ = knn.fit(X, y).predict(T)
 
     plt.subplot(2, 1, i + 1)
-    plt.scatter(X, y, color='darkorange', label='data')
-    plt.plot(T, y_, color='navy', label='prediction')
-    plt.axis('tight')
+    plt.scatter(X, y, color="darkorange", label="data")
+    plt.plot(T, y_, color="navy", label="prediction")
+    plt.axis("tight")
     plt.legend()
-    plt.title("KNeighborsRegressor (k = %i, weights = '%s')" % (n_neighbors,
-                                                                weights))
+    plt.title("KNeighborsRegressor (k = %i, weights = '%s')" % (n_neighbors, weights))
 
 plt.tight_layout()
 plt.show()
