@@ -1,6 +1,4 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 =============================================================
 Compare the effect of different scalers on data with outliers
@@ -65,58 +63,60 @@ from sklearn.preprocessing import PowerTransformer
 
 from sklearn.datasets import fetch_california_housing
 
-print(__doc__)
-
 dataset = fetch_california_housing()
 X_full, y_full = dataset.data, dataset.target
 feature_names = dataset.feature_names
 
 feature_mapping = {
-    'MedInc': 'Median income in block',
-    'HousAge': 'Median house age in block',
-    'AveRooms': 'Average number of rooms',
-    'AveBedrms': 'Average number of bedrooms',
-    'Population': 'Block population',
-    'AveOccup': 'Average house occupancy',
-    'Latitude': 'House block latitude',
-    'Longitude': 'House block longitude'
+    "MedInc": "Median income in block",
+    "HousAge": "Median house age in block",
+    "AveRooms": "Average number of rooms",
+    "AveBedrms": "Average number of bedrooms",
+    "Population": "Block population",
+    "AveOccup": "Average house occupancy",
+    "Latitude": "House block latitude",
+    "Longitude": "House block longitude",
 }
 
 # Take only 2 features to make visualization easier
 # Feature MedInc has a long tail distribution.
 # Feature AveOccup has a few but very large outliers.
-features = ['MedInc', 'AveOccup']
+features = ["MedInc", "AveOccup"]
 features_idx = [feature_names.index(feature) for feature in features]
 X = X_full[:, features_idx]
 distributions = [
-    ('Unscaled data', X),
-    ('Data after standard scaling',
-        StandardScaler().fit_transform(X)),
-    ('Data after min-max scaling',
-        MinMaxScaler().fit_transform(X)),
-    ('Data after max-abs scaling',
-        MaxAbsScaler().fit_transform(X)),
-    ('Data after robust scaling',
-        RobustScaler(quantile_range=(25, 75)).fit_transform(X)),
-    ('Data after power transformation (Yeo-Johnson)',
-     PowerTransformer(method='yeo-johnson').fit_transform(X)),
-    ('Data after power transformation (Box-Cox)',
-     PowerTransformer(method='box-cox').fit_transform(X)),
-    ('Data after quantile transformation (uniform pdf)',
-        QuantileTransformer(output_distribution='uniform')
-        .fit_transform(X)),
-    ('Data after quantile transformation (gaussian pdf)',
-        QuantileTransformer(output_distribution='normal')
-        .fit_transform(X)),
-    ('Data after sample-wise L2 normalizing',
-        Normalizer().fit_transform(X)),
+    ("Unscaled data", X),
+    ("Data after standard scaling", StandardScaler().fit_transform(X)),
+    ("Data after min-max scaling", MinMaxScaler().fit_transform(X)),
+    ("Data after max-abs scaling", MaxAbsScaler().fit_transform(X)),
+    (
+        "Data after robust scaling",
+        RobustScaler(quantile_range=(25, 75)).fit_transform(X),
+    ),
+    (
+        "Data after power transformation (Yeo-Johnson)",
+        PowerTransformer(method="yeo-johnson").fit_transform(X),
+    ),
+    (
+        "Data after power transformation (Box-Cox)",
+        PowerTransformer(method="box-cox").fit_transform(X),
+    ),
+    (
+        "Data after quantile transformation (uniform pdf)",
+        QuantileTransformer(output_distribution="uniform").fit_transform(X),
+    ),
+    (
+        "Data after quantile transformation (gaussian pdf)",
+        QuantileTransformer(output_distribution="normal").fit_transform(X),
+    ),
+    ("Data after sample-wise L2 normalizing", Normalizer().fit_transform(X)),
 ]
 
 # scale the output between 0 and 1 for the colorbar
 y = minmax_scale(y_full)
 
 # plasma does not exist in matplotlib < 1.5
-cmap = getattr(cm, 'plasma_r', cm.hot_r)
+cmap = getattr(cm, "plasma_r", cm.hot_r)
 
 
 def create_axes(title, figsize=(16, 6)):
@@ -155,13 +155,14 @@ def create_axes(title, figsize=(16, 6)):
     rect_colorbar = [left, bottom, width, height]
     ax_colorbar = plt.axes(rect_colorbar)
 
-    return ((ax_scatter, ax_histy, ax_histx),
-            (ax_scatter_zoom, ax_histy_zoom, ax_histx_zoom),
-            ax_colorbar)
+    return (
+        (ax_scatter, ax_histy, ax_histx),
+        (ax_scatter_zoom, ax_histy_zoom, ax_histx_zoom),
+        ax_colorbar,
+    )
 
 
-def plot_distribution(axes, X, y, hist_nbins=50, title="",
-                      x0_label="", x1_label=""):
+def plot_distribution(axes, X, y, hist_nbins=50, title="", x0_label="", x1_label=""):
     ax, hist_X1, hist_X0 = axes
 
     ax.set_title(title)
@@ -170,28 +171,31 @@ def plot_distribution(axes, X, y, hist_nbins=50, title="",
 
     # The scatter plot
     colors = cmap(y)
-    ax.scatter(X[:, 0], X[:, 1], alpha=0.5, marker='o', s=5, lw=0, c=colors)
+    ax.scatter(X[:, 0], X[:, 1], alpha=0.5, marker="o", s=5, lw=0, c=colors)
 
     # Removing the top and the right spine for aesthetics
     # make nice axis layout
-    ax.spines['top'].set_visible(False)
-    ax.spines['right'].set_visible(False)
+    ax.spines["top"].set_visible(False)
+    ax.spines["right"].set_visible(False)
     ax.get_xaxis().tick_bottom()
     ax.get_yaxis().tick_left()
-    ax.spines['left'].set_position(('outward', 10))
-    ax.spines['bottom'].set_position(('outward', 10))
+    ax.spines["left"].set_position(("outward", 10))
+    ax.spines["bottom"].set_position(("outward", 10))
 
     # Histogram for axis X1 (feature 5)
     hist_X1.set_ylim(ax.get_ylim())
-    hist_X1.hist(X[:, 1], bins=hist_nbins, orientation='horizontal',
-                 color='grey', ec='grey')
-    hist_X1.axis('off')
+    hist_X1.hist(
+        X[:, 1], bins=hist_nbins, orientation="horizontal", color="grey", ec="grey"
+    )
+    hist_X1.axis("off")
 
     # Histogram for axis X0 (feature 0)
     hist_X0.set_xlim(ax.get_xlim())
-    hist_X0.hist(X[:, 0], bins=hist_nbins, orientation='vertical',
-                 color='grey', ec='grey')
-    hist_X0.axis('off')
+    hist_X0.hist(
+        X[:, 0], bins=hist_nbins, orientation="vertical", color="grey", ec="grey"
+    )
+    hist_X0.axis("off")
+
 
 # %%
 # Two plots will be shown for each scaler/normalizer/transformer. The left
@@ -205,29 +209,42 @@ def make_plot(item_idx):
     title, X = distributions[item_idx]
     ax_zoom_out, ax_zoom_in, ax_colorbar = create_axes(title)
     axarr = (ax_zoom_out, ax_zoom_in)
-    plot_distribution(axarr[0], X, y, hist_nbins=200,
-                      x0_label=feature_mapping[features[0]],
-                      x1_label=feature_mapping[features[1]],
-                      title="Full data")
+    plot_distribution(
+        axarr[0],
+        X,
+        y,
+        hist_nbins=200,
+        x0_label=feature_mapping[features[0]],
+        x1_label=feature_mapping[features[1]],
+        title="Full data",
+    )
 
     # zoom-in
     zoom_in_percentile_range = (0, 99)
     cutoffs_X0 = np.percentile(X[:, 0], zoom_in_percentile_range)
     cutoffs_X1 = np.percentile(X[:, 1], zoom_in_percentile_range)
 
-    non_outliers_mask = (
-        np.all(X > [cutoffs_X0[0], cutoffs_X1[0]], axis=1) &
-        np.all(X < [cutoffs_X0[1], cutoffs_X1[1]], axis=1))
-    plot_distribution(axarr[1], X[non_outliers_mask], y[non_outliers_mask],
-                      hist_nbins=50,
-                      x0_label=feature_mapping[features[0]],
-                      x1_label=feature_mapping[features[1]],
-                      title="Zoom-in")
+    non_outliers_mask = np.all(X > [cutoffs_X0[0], cutoffs_X1[0]], axis=1) & np.all(
+        X < [cutoffs_X0[1], cutoffs_X1[1]], axis=1
+    )
+    plot_distribution(
+        axarr[1],
+        X[non_outliers_mask],
+        y[non_outliers_mask],
+        hist_nbins=50,
+        x0_label=feature_mapping[features[0]],
+        x1_label=feature_mapping[features[1]],
+        title="Zoom-in",
+    )
 
     norm = mpl.colors.Normalize(y_full.min(), y_full.max())
-    mpl.colorbar.ColorbarBase(ax_colorbar, cmap=cmap,
-                              norm=norm, orientation='vertical',
-                              label='Color mapping for values of y')
+    mpl.colorbar.ColorbarBase(
+        ax_colorbar,
+        cmap=cmap,
+        norm=norm,
+        orientation="vertical",
+        label="Color mapping for values of y",
+    )
 
 
 # %%
