@@ -1,4 +1,4 @@
-'''
+"""
 ==================
 RBF SVM parameters
 ==================
@@ -73,8 +73,7 @@ expense of compute time. Increasing the value number of ``C_range`` and
 ``gamma_range`` steps will increase the resolution of the hyper-parameter heat
 map.
 
-'''
-print(__doc__)
+"""
 
 import numpy as np
 import matplotlib.pyplot as plt
@@ -90,8 +89,8 @@ from sklearn.model_selection import GridSearchCV
 # Utility function to move the midpoint of a colormap to be around
 # the values of interest.
 
-class MidpointNormalize(Normalize):
 
+class MidpointNormalize(Normalize):
     def __init__(self, vmin=None, vmax=None, midpoint=None, clip=False):
         self.midpoint = midpoint
         Normalize.__init__(self, vmin, vmax, clip)
@@ -100,6 +99,7 @@ class MidpointNormalize(Normalize):
         x, y = [self.vmin, self.midpoint, self.vmax], [0, 0.5, 1]
         return np.ma.masked_array(np.interp(value, x, y))
 
+
 # #############################################################################
 # Load and prepare data set
 #
@@ -142,8 +142,10 @@ cv = StratifiedShuffleSplit(n_splits=5, test_size=0.2, random_state=42)
 grid = GridSearchCV(SVC(), param_grid=param_grid, cv=cv)
 grid.fit(X, y)
 
-print("The best parameters are %s with a score of %0.2f"
-      % (grid.best_params_, grid.best_score_))
+print(
+    "The best parameters are %s with a score of %0.2f"
+    % (grid.best_params_, grid.best_score_)
+)
 
 # Now we need to fit a classifier for all parameters in the 2d version
 # (we use a smaller set of parameters here because it takes a while to train)
@@ -171,19 +173,16 @@ for (k, (C, gamma, clf)) in enumerate(classifiers):
 
     # visualize decision function for these parameters
     plt.subplot(len(C_2d_range), len(gamma_2d_range), k + 1)
-    plt.title("gamma=10^%d, C=10^%d" % (np.log10(gamma), np.log10(C)),
-              size='medium')
+    plt.title("gamma=10^%d, C=10^%d" % (np.log10(gamma), np.log10(C)), size="medium")
 
     # visualize parameter's effect on decision function
     plt.pcolormesh(xx, yy, -Z, cmap=plt.cm.RdBu)
-    plt.scatter(X_2d[:, 0], X_2d[:, 1], c=y_2d, cmap=plt.cm.RdBu_r,
-                edgecolors='k')
+    plt.scatter(X_2d[:, 0], X_2d[:, 1], c=y_2d, cmap=plt.cm.RdBu_r, edgecolors="k")
     plt.xticks(())
     plt.yticks(())
-    plt.axis('tight')
+    plt.axis("tight")
 
-scores = grid.cv_results_['mean_test_score'].reshape(len(C_range),
-                                                     len(gamma_range))
+scores = grid.cv_results_["mean_test_score"].reshape(len(C_range), len(gamma_range))
 
 # Draw heatmap of the validation accuracy as a function of gamma and C
 #
@@ -195,13 +194,17 @@ scores = grid.cv_results_['mean_test_score'].reshape(len(C_range),
 # the same color.
 
 plt.figure(figsize=(8, 6))
-plt.subplots_adjust(left=.2, right=0.95, bottom=0.15, top=0.95)
-plt.imshow(scores, interpolation='nearest', cmap=plt.cm.hot,
-           norm=MidpointNormalize(vmin=0.2, midpoint=0.92))
-plt.xlabel('gamma')
-plt.ylabel('C')
+plt.subplots_adjust(left=0.2, right=0.95, bottom=0.15, top=0.95)
+plt.imshow(
+    scores,
+    interpolation="nearest",
+    cmap=plt.cm.hot,
+    norm=MidpointNormalize(vmin=0.2, midpoint=0.92),
+)
+plt.xlabel("gamma")
+plt.ylabel("C")
 plt.colorbar()
 plt.xticks(np.arange(len(gamma_range)), gamma_range, rotation=45)
 plt.yticks(np.arange(len(C_range)), C_range)
-plt.title('Validation accuracy')
+plt.title("Validation accuracy")
 plt.show()
