@@ -6,8 +6,8 @@ SVM: Maximum margin separating hyperplane
 Plot the maximum margin separating hyperplane within a two-class
 separable dataset using a Support Vector Machine classifier with
 linear kernel.
+
 """
-print(__doc__)
 
 import numpy as np
 import matplotlib.pyplot as plt
@@ -19,7 +19,7 @@ from sklearn.datasets import make_blobs
 X, y = make_blobs(n_samples=40, centers=2, random_state=6)
 
 # fit the model, don't regularize for illustration purposes
-clf = svm.SVC(kernel='linear', C=1000)
+clf = svm.SVC(kernel="linear", C=1000)
 clf.fit(X, y)
 
 plt.scatter(X[:, 0], X[:, 1], c=y, s=30, cmap=plt.cm.Paired)
@@ -37,9 +37,16 @@ xy = np.vstack([XX.ravel(), YY.ravel()]).T
 Z = clf.decision_function(xy).reshape(XX.shape)
 
 # plot decision boundary and margins
-ax.contour(XX, YY, Z, colors='k', levels=[-1, 0, 1], alpha=0.5,
-           linestyles=['--', '-', '--'])
+ax.contour(
+    XX, YY, Z, colors="k", levels=[-1, 0, 1], alpha=0.5, linestyles=["--", "-", "--"]
+)
 # plot support vectors
-ax.scatter(clf.support_vectors_[:, 0], clf.support_vectors_[:, 1], s=100,
-           linewidth=1, facecolors='none', edgecolors='k')
+ax.scatter(
+    clf.support_vectors_[:, 0],
+    clf.support_vectors_[:, 1],
+    s=100,
+    linewidth=1,
+    facecolors="none",
+    edgecolors="k",
+)
 plt.show()
