@@ -7,8 +7,8 @@ This example shows how to perform univariate feature selection before running a
 SVC (support vector classifier) to improve the classification scores. We use
 the iris dataset (4 features) and add 36 non-informative features. We can find
 that our model achieves best performance when we select around 10% of features.
+
 """
-print(__doc__)
 
 import numpy as np
 import matplotlib.pyplot as plt
@@ -29,10 +29,14 @@ X = np.hstack((X, 2 * np.random.random((X.shape[0], 36))))
 
 # #############################################################################
 # Create a feature-selection transform, a scaler and an instance of SVM that we
-# combine together to have an full-blown estimator
-clf = Pipeline([('anova', SelectPercentile(chi2)),
-                ('scaler', StandardScaler()),
-                ('svc', SVC(gamma="auto"))])
+# combine together to have a full-blown estimator
+clf = Pipeline(
+    [
+        ("anova", SelectPercentile(chi2)),
+        ("scaler", StandardScaler()),
+        ("svc", SVC(gamma="auto")),
+    ]
+)
 
 # #############################################################################
 # Plot the cross-validation score as a function of percentile of features
@@ -47,10 +51,9 @@ for percentile in percentiles:
     score_stds.append(this_scores.std())
 
 plt.errorbar(percentiles, score_means, np.array(score_stds))
-plt.title(
-    'Performance of the SVM-Anova varying the percentile of features selected')
+plt.title("Performance of the SVM-Anova varying the percentile of features selected")
 plt.xticks(np.linspace(0, 100, 11, endpoint=True))
-plt.xlabel('Percentile')
-plt.ylabel('Accuracy Score')
-plt.axis('tight')
+plt.xlabel("Percentile")
+plt.ylabel("Accuracy Score")
+plt.axis("tight")
 plt.show()
