@@ -52,6 +52,7 @@ necessary to get a good convergence.
 # Author: Peter Prettenhofer <peter.prettenhofer@gmail.com>
 #         Lars Buitinck
 # License: BSD 3 clause
+
 from sklearn.datasets import fetch_20newsgroups
 from sklearn.decomposition import TruncatedSVD
 from sklearn.feature_extraction.text import TfidfVectorizer
@@ -72,36 +73,57 @@ import numpy as np
 
 
 # Display progress logs on stdout
-logging.basicConfig(level=logging.INFO,
-                    format='%(asctime)s %(levelname)s %(message)s')
+logging.basicConfig(level=logging.INFO, format="%(asctime)s %(levelname)s %(message)s")
 
 # parse commandline arguments
 op = OptionParser()
-op.add_option("--lsa",
-              dest="n_components", type="int",
-              help="Preprocess documents with latent semantic analysis.")
-op.add_option("--no-minibatch",
-              action="store_false", dest="minibatch", default=True,
-              help="Use ordinary k-means algorithm (in batch mode).")
-op.add_option("--no-idf",
-              action="store_false", dest="use_idf", default=True,
-              help="Disable Inverse Document Frequency feature weighting.")
-op.add_option("--use-hashing",
-              action="store_true", default=False,
-              help="Use a hashing feature vectorizer")
-op.add_option("--n-features", type=int, default=10000,
-              help="Maximum number of features (dimensions)"
-                   " to extract from text.")
-op.add_option("--verbose",
-              action="store_true", dest="verbose", default=False,
-              help="Print progress reports inside k-means algorithm.")
+op.add_option(
+    "--lsa",
+    dest="n_components",
+    type="int",
+    help="Preprocess documents with latent semantic analysis.",
+)
+op.add_option(
+    "--no-minibatch",
+    action="store_false",
+    dest="minibatch",
+    default=True,
+    help="Use ordinary k-means algorithm (in batch mode).",
+)
+op.add_option(
+    "--no-idf",
+    action="store_false",
+    dest="use_idf",
+    default=True,
+    help="Disable Inverse Document Frequency feature weighting.",
+)
+op.add_option(
+    "--use-hashing",
+    action="store_true",
+    default=False,
+    help="Use a hashing feature vectorizer",
+)
+op.add_option(
+    "--n-features",
+    type=int,
+    default=10000,
+    help="Maximum number of features (dimensions) to extract from text.",
+)
+op.add_option(
+    "--verbose",
+    action="store_true",
+    dest="verbose",
+    default=False,
+    help="Print progress reports inside k-means algorithm.",
+)
 
 print(__doc__)
 op.print_help()
+print()
 
 
 def is_interactive():
-    return not hasattr(sys.modules['__main__'], '__file__')
+    return not hasattr(sys.modules["__main__"], "__file__")
 
 
 # work-around for Jupyter notebook and IPython console
@@ -115,10 +137,10 @@ if len(args) > 0:
 # #############################################################################
 # Load some categories from the training set
 categories = [
-    'alt.atheism',
-    'talk.religion.misc',
-    'comp.graphics',
-    'sci.space',
+    "alt.atheism",
+    "talk.religion.misc",
+    "comp.graphics",
+    "sci.space",
 ]
 # Uncomment the following to do the analysis on all the categories
 # categories = None
@@ -126,8 +148,9 @@ categories = [
 print("Loading 20 newsgroups dataset for categories:")
 print(categories)
 
-dataset = fetch_20newsgroups(subset='all', categories=categories,
-                             shuffle=True, random_state=42)
+dataset = fetch_20newsgroups(
+    subset="all", categories=categories, shuffle=True, random_state=42
+)
 
 print("%d documents" % len(dataset.data))
 print("%d categories" % len(dataset.target_names))
@@ -136,24 +159,33 @@ print()
 labels = dataset.target
 true_k = np.unique(labels).shape[0]
 
-print("Extracting features from the training dataset "
-      "using a sparse vectorizer")
+print("Extracting features from the training dataset using a sparse vectorizer")
 t0 = time()
 if opts.use_hashing:
     if opts.use_idf:
         # Perform an IDF normalization on the output of HashingVectorizer
-        hasher = HashingVectorizer(n_features=opts.n_features,
-                                   stop_words='english', alternate_sign=False,
-                                   norm=None)
+        hasher = HashingVectorizer(
+            n_features=opts.n_features,
+            stop_words="english",
+            alternate_sign=False,
+            norm=None,
+        )
         vectorizer = make_pipeline(hasher, TfidfTransformer())
     else:
-        vectorizer = HashingVectorizer(n_features=opts.n_features,
-                                       stop_words='english',
-                                       alternate_sign=False, norm='l2')
+        vectorizer = HashingVectorizer(
+            n_features=opts.n_features,
+            stop_words="english",
+            alternate_sign=False,
+            norm="l2",
+        )
 else:
-    vectorizer = TfidfVectorizer(max_df=0.5, max_features=opts.n_features,
-                                 min_df=2, stop_words='english',
-                                 use_idf=opts.use_idf)
+    vectorizer = TfidfVectorizer(
+        max_df=0.5,
+        max_features=opts.n_features,
+        min_df=2,
+        stop_words="english",
+        use_idf=opts.use_idf,
+    )
 X = vectorizer.fit_transform(dataset.data)
 
 print("done in %fs" % (time() - t0))
@@ -175,8 +207,9 @@ if opts.n_components:
     print("done in %fs" % (time() - t0))
 
     explained_variance = svd.explained_variance_ratio_.sum()
-    print("Explained variance of the SVD step: {}%".format(
-        int(explained_variance * 100)))
+    print(
+        "Explained variance of the SVD step: {}%".format(int(explained_variance * 100))
+    )
 
     print()
 
@@ -185,11 +218,22 @@ if opts.n_components:
 # Do the actual clustering
 
 if opts.minibatch:
-    km = MiniBatchKMeans(n_clusters=true_k, init='k-means++', n_init=1,
-                         init_size=1000, batch_size=1000, verbose=opts.verbose)
+    km = MiniBatchKMeans(
+        n_clusters=true_k,
+        init="k-means++",
+        n_init=1,
+        init_size=1000,
+        batch_size=1000,
+        verbose=opts.verbose,
+    )
 else:
-    km = KMeans(n_clusters=true_k, init='k-means++', max_iter=100, n_init=1,
-                verbose=opts.verbose)
+    km = KMeans(
+        n_clusters=true_k,
+        init="k-means++",
+        max_iter=100,
+        n_init=1,
+        verbose=opts.verbose,
+    )
 
 print("Clustering sparse data with %s" % km)
 t0 = time()
@@ -200,10 +244,11 @@ print()
 print("Homogeneity: %0.3f" % metrics.homogeneity_score(labels, km.labels_))
 print("Completeness: %0.3f" % metrics.completeness_score(labels, km.labels_))
 print("V-measure: %0.3f" % metrics.v_measure_score(labels, km.labels_))
-print("Adjusted Rand-Index: %.3f"
-      % metrics.adjusted_rand_score(labels, km.labels_))
-print("Silhouette Coefficient: %0.3f"
-      % metrics.silhouette_score(X, km.labels_, sample_size=1000))
+print("Adjusted Rand-Index: %.3f" % metrics.adjusted_rand_score(labels, km.labels_))
+print(
+    "Silhouette Coefficient: %0.3f"
+    % metrics.silhouette_score(X, km.labels_, sample_size=1000)
+)
 
 print()
 
@@ -219,7 +264,7 @@ if not opts.use_hashing:
 
     terms = vectorizer.get_feature_names_out()
     for i in range(true_k):
-        print("Cluster %d:" % i, end='')
+        print("Cluster %d:" % i, end="")
         for ind in order_centroids[i, :10]:
-            print(' %s' % terms[ind], end='')
+            print(" %s" % terms[ind], end="")
         print()
