@@ -5,16 +5,21 @@ import pytest
 from sklearn.ensemble._hist_gradient_boosting.binning import (
     _BinMapper,
     _find_binning_thresholds,
-    _map_to_bins
+    _map_to_bins,
 )
 from sklearn.ensemble._hist_gradient_boosting.common import X_DTYPE
 from sklearn.ensemble._hist_gradient_boosting.common import X_BINNED_DTYPE
 from sklearn.ensemble._hist_gradient_boosting.common import ALMOST_INF
+from sklearn.utils._openmp_helpers import _openmp_effective_n_threads
+
+n_threads = _openmp_effective_n_threads()
 
 
-DATA = np.random.RandomState(42).normal(
-    loc=[0, 10], scale=[1, 0.01], size=(int(1e6), 2)
-).astype(X_DTYPE)
+DATA = (
+    np.random.RandomState(42)
+    .normal(loc=[0, 10], scale=[1, 0.01], size=(int(1e6), 2))
+    .astype(X_DTYPE)
+)
 
 
 def test_find_binning_thresholds_regular_data():
@@ -36,57 +41,62 @@ def test_find_binning_thresholds_small_regular_data():
     assert_allclose(bin_thresholds, [1, 2, 3, 4, 5, 6, 7, 8, 9])
 
     bin_thresholds = _find_binning_thresholds(data, max_bins=11)
-    assert_allclose(bin_thresholds, np.arange(10) + .5)
+    assert_allclose(bin_thresholds, np.arange(10) + 0.5)
 
     bin_thresholds = _find_binning_thresholds(data, max_bins=255)
-    assert_allclose(bin_thresholds, np.arange(10) + .5)
+    assert_allclose(bin_thresholds, np.arange(10) + 0.5)
 
 
 def test_find_binning_thresholds_random_data():
-    bin_thresholds = [_find_binning_thresholds(DATA[:, i], max_bins=255)
-                      for i in range(2)]
+    bin_thresholds = [
+        _find_binning_thresholds(DATA[:, i], max_bins=255) for i in range(2)
+    ]
     for i in range(len(bin_thresholds)):
         assert bin_thresholds[i].shape == (254,)  # 255 - 1
         assert bin_thresholds[i].dtype == DATA.dtype
 
-    assert_allclose(bin_thresholds[0][[64, 128, 192]],
-                    np.array([-0.7, 0.0, 0.7]), atol=1e-1)
+    assert_allclose(
+        bin_thresholds[0][[64, 128, 192]], np.array([-0.7, 0.0, 0.7]), atol=1e-1
+    )
 
-    assert_allclose(bin_thresholds[1][[64, 128, 192]],
-                    np.array([9.99, 10.00, 10.01]), atol=1e-2)
+    assert_allclose(
+        bin_thresholds[1][[64, 128, 192]], np.array([9.99, 10.00, 10.01]), atol=1e-2
+    )
 
 
 def test_find_binning_thresholds_low_n_bins():
-    bin_thresholds = [_find_binning_thresholds(DATA[:, i], max_bins=128)
-                      for i in range(2)]
+    bin_thresholds = [
+        _find_binning_thresholds(DATA[:, i], max_bins=128) for i in range(2)
+    ]
     for i in range(len(bin_thresholds)):
         assert bin_thresholds[i].shape == (127,)  # 128 - 1
         assert bin_thresholds[i].dtype == DATA.dtype
 
 
-@pytest.mark.parametrize('n_bins', (2, 257))
+@pytest.mark.parametrize("n_bins", (2, 257))
 def test_invalid_n_bins(n_bins):
-    err_msg = (
-        'n_bins={} should be no smaller than 3 and no larger than 256'
-        .format(n_bins))
+    err_msg = "n_bins={} should be no smaller than 3 and no larger than 256".format(
+        n_bins
+    )
     with pytest.raises(ValueError, match=err_msg):
         _BinMapper(n_bins=n_bins).fit(DATA)
 
 
 def test_bin_mapper_n_features_transform():
     mapper = _BinMapper(n_bins=42, random_state=42).fit(DATA)
-    err_msg = 'This estimator was fitted with 2 features but 4 got passed'
+    err_msg = "This estimator was fitted with 2 features but 4 got passed"
     with pytest.raises(ValueError, match=err_msg):
         mapper.transform(np.repeat(DATA, 2, axis=1))
 
 
-@pytest.mark.parametrize('max_bins', [16, 128, 255])
+@pytest.mark.parametrize("max_bins", [16, 128, 255])
 def test_map_to_bins(max_bins):
-    bin_thresholds = [_find_binning_thresholds(DATA[:, i], max_bins=max_bins)
-                      for i in range(2)]
-    binned = np.zeros_like(DATA, dtype=X_BINNED_DTYPE, order='F')
+    bin_thresholds = [
+        _find_binning_thresholds(DATA[:, i], max_bins=max_bins) for i in range(2)
+    ]
+    binned = np.zeros_like(DATA, dtype=X_BINNED_DTYPE, order="F")
     last_bin_idx = max_bins
-    _map_to_bins(DATA, bin_thresholds, last_bin_idx, binned)
+    _map_to_bins(DATA, bin_thresholds, last_bin_idx, n_threads, binned)
     assert binned.shape == DATA.shape
     assert binned.dtype == np.uint8
     assert binned.flags.f_contiguous
@@ -115,8 +125,7 @@ def test_bin_mapper_random_data(max_bins):
     assert binned.shape == (n_samples, n_features)
     assert binned.dtype == np.uint8
     assert_array_equal(binned.min(axis=0), np.array([0, 0]))
-    assert_array_equal(binned.max(axis=0),
-                       np.array([max_bins - 1, max_bins - 1]))
+    assert_array_equal(binned.max(axis=0), np.array([max_bins - 1, max_bins - 1]))
     assert len(mapper.bin_thresholds_) == n_features
     for bin_thresholds_feature in mapper.bin_thresholds_:
         assert bin_thresholds_feature.shape == (max_bins - 1,)
@@ -130,12 +139,7 @@ def test_bin_mapper_random_data(max_bins):
             assert abs(count - expected_count_per_bin) < tol
 
 
-@pytest.mark.parametrize("n_samples, max_bins", [
-    (5, 5),
-    (5, 10),
-    (5, 11),
-    (42, 255)
-])
+@pytest.mark.parametrize("n_samples, max_bins", [(5, 5), (5, 10), (5, 11), (42, 255)])
 def test_bin_mapper_small_random_data(n_samples, max_bins):
     data = np.random.RandomState(42).normal(size=n_samples).reshape(-1, 1)
     assert len(np.unique(data)) == n_samples
@@ -147,15 +151,17 @@ def test_bin_mapper_small_random_data(n_samples, max_bins):
 
     assert binned.shape == data.shape
     assert binned.dtype == np.uint8
-    assert_array_equal(binned.ravel()[np.argsort(data.ravel())],
-                       np.arange(n_samples))
+    assert_array_equal(binned.ravel()[np.argsort(data.ravel())], np.arange(n_samples))
 
 
-@pytest.mark.parametrize("max_bins, n_distinct, multiplier", [
-    (5, 5, 1),
-    (5, 5, 3),
-    (255, 12, 42),
-])
+@pytest.mark.parametrize(
+    "max_bins, n_distinct, multiplier",
+    [
+        (5, 5, 1),
+        (5, 5, 3),
+        (255, 12, 42),
+    ],
+)
 def test_bin_mapper_identity_repeated_values(max_bins, n_distinct, multiplier):
     data = np.array(list(range(n_distinct)) * multiplier).reshape(-1, 1)
     # max_bins is the number of bins for non-missing values
@@ -164,7 +170,7 @@ def test_bin_mapper_identity_repeated_values(max_bins, n_distinct, multiplier):
     assert_array_equal(data, binned)
 
 
-@pytest.mark.parametrize('n_distinct', [2, 7, 42])
+@pytest.mark.parametrize("n_distinct", [2, 7, 42])
 def test_bin_mapper_repeated_values_invariance(n_distinct):
     rng = np.random.RandomState(42)
     distinct_values = rng.normal(size=n_distinct)
@@ -189,11 +195,14 @@ def test_bin_mapper_repeated_values_invariance(n_distinct):
     assert_array_equal(binned_1, binned_2)
 
 
-@pytest.mark.parametrize("max_bins, scale, offset", [
-    (3, 2, -1),
-    (42, 1, 0),
-    (255, 0.3, 42),
-])
+@pytest.mark.parametrize(
+    "max_bins, scale, offset",
+    [
+        (3, 2, -1),
+        (42, 1, 0),
+        (255, 0.3, 42),
+    ],
+)
 def test_bin_mapper_identity_small(max_bins, scale, offset):
     data = np.arange(max_bins).reshape(-1, 1) * scale + offset
     # max_bins is the number of bins for non-missing values
@@ -202,15 +211,18 @@ def test_bin_mapper_identity_small(max_bins, scale, offset):
     assert_array_equal(binned, np.arange(max_bins).reshape(-1, 1))
 
 
-@pytest.mark.parametrize('max_bins_small, max_bins_large', [
-    (2, 2),
-    (3, 3),
-    (4, 4),
-    (42, 42),
-    (255, 255),
-    (5, 17),
-    (42, 255),
-])
+@pytest.mark.parametrize(
+    "max_bins_small, max_bins_large",
+    [
+        (2, 2),
+        (3, 3),
+        (4, 4),
+        (42, 42),
+        (255, 255),
+        (5, 17),
+        (42, 255),
+    ],
+)
 def test_bin_mapper_idempotence(max_bins_small, max_bins_large):
     assert max_bins_large >= max_bins_small
     data = np.random.RandomState(42).normal(size=30000).reshape(-1, 1)
@@ -221,8 +233,8 @@ def test_bin_mapper_idempotence(max_bins_small, max_bins_large):
     assert_array_equal(binned_small, binned_large)
 
 
-@pytest.mark.parametrize('n_bins', [10, 100, 256])
-@pytest.mark.parametrize('diff', [-5, 0, 5])
+@pytest.mark.parametrize("n_bins", [10, 100, 256])
+@pytest.mark.parametrize("diff", [-5, 0, 5])
 def test_n_bins_non_missing(n_bins, diff):
     # Check that n_bins_non_missing is n_unique_values when
     # there are not a lot of unique values, else n_bins - 1.
@@ -231,8 +243,7 @@ def test_n_bins_non_missing(n_bins, diff):
     X = list(range(n_unique_values)) * 2
     X = np.array(X).reshape(-1, 1)
     mapper = _BinMapper(n_bins=n_bins).fit(X)
-    assert np.all(mapper.n_bins_non_missing_ == min(
-        n_bins - 1, n_unique_values))
+    assert np.all(mapper.n_bins_non_missing_ == min(n_bins - 1, n_unique_values))
 
 
 def test_subsample():
@@ -241,35 +252,54 @@ def test_subsample():
     mapper_subsample = _BinMapper(subsample=256, random_state=0).fit(DATA)
 
     for feature in range(DATA.shape[1]):
-        assert not np.allclose(mapper_no_subsample.bin_thresholds_[feature],
-                               mapper_subsample.bin_thresholds_[feature],
-                               rtol=1e-4)
+        assert not np.allclose(
+            mapper_no_subsample.bin_thresholds_[feature],
+            mapper_subsample.bin_thresholds_[feature],
+            rtol=1e-4,
+        )
 
 
 @pytest.mark.parametrize(
-    'n_bins, n_bins_non_missing, X_trans_expected', [
-        (256, [4, 2, 2], [[0,   0,   0],  # 255 <=> missing value
-                          [255, 255, 0],
-                          [1,   0,   0],
-                          [255, 1,   1],
-                          [2,   1,   1],
-                          [3,   0,   0]]),
-        (3, [2, 2, 2], [[0, 0, 0],  # 2 <=> missing value
-                        [2, 2, 0],
-                        [0, 0, 0],
-                        [2, 1, 1],
-                        [1, 1, 1],
-                        [1, 0, 0]])])
+    "n_bins, n_bins_non_missing, X_trans_expected",
+    [
+        (
+            256,
+            [4, 2, 2],
+            [
+                [0, 0, 0],  # 255 <=> missing value
+                [255, 255, 0],
+                [1, 0, 0],
+                [255, 1, 1],
+                [2, 1, 1],
+                [3, 0, 0],
+            ],
+        ),
+        (
+            3,
+            [2, 2, 2],
+            [
+                [0, 0, 0],  # 2 <=> missing value
+                [2, 2, 0],
+                [0, 0, 0],
+                [2, 1, 1],
+                [1, 1, 1],
+                [1, 0, 0],
+            ],
+        ),
+    ],
+)
 def test_missing_values_support(n_bins, n_bins_non_missing, X_trans_expected):
     # check for missing values: make sure nans are mapped to the last bin
     # and that the _BinMapper attributes are correct
 
-    X = [[1,      1,      0],
-         [np.NaN, np.NaN, 0],
-         [2,      1,      0],
-         [np.NaN, 2,      1],
-         [3,      2,      1],
-         [4,      1,      0]]
+    X = [
+        [1, 1, 0],
+        [np.NaN, np.NaN, 0],
+        [2, 1, 0],
+        [np.NaN, 2, 1],
+        [3, 2, 1],
+        [4, 1, 0],
+    ]
 
     X = np.array(X)
 
@@ -279,8 +309,10 @@ def test_missing_values_support(n_bins, n_bins_non_missing, X_trans_expected):
     assert_array_equal(mapper.n_bins_non_missing_, n_bins_non_missing)
 
     for feature_idx in range(X.shape[1]):
-        assert len(mapper.bin_thresholds_[feature_idx]) == \
-            n_bins_non_missing[feature_idx] - 1
+        assert (
+            len(mapper.bin_thresholds_[feature_idx])
+            == n_bins_non_missing[feature_idx] - 1
+        )
 
     assert mapper.missing_values_bin_idx_ == n_bins - 1
 
@@ -292,10 +324,10 @@ def test_infinite_values():
     # Make sure infinite values are properly handled.
     bin_mapper = _BinMapper()
 
-    X = np.array([-np.inf, 0, 1,  np.inf]).reshape(-1, 1)
+    X = np.array([-np.inf, 0, 1, np.inf]).reshape(-1, 1)
 
     bin_mapper.fit(X)
-    assert_allclose(bin_mapper.bin_thresholds_[0], [-np.inf, .5, ALMOST_INF])
+    assert_allclose(bin_mapper.bin_thresholds_[0], [-np.inf, 0.5, ALMOST_INF])
     assert bin_mapper.n_bins_non_missing_ == [4]
 
     expected_binned_X = np.array([0, 1, 2, 3]).reshape(-1, 1)
@@ -307,18 +339,17 @@ def test_categorical_feature(n_bins):
     # Basic test for categorical features
     # we make sure that categories are mapped into [0, n_categories - 1] and
     # that nans are mapped to the last bin
-    X = np.array([[4] * 500 +
-                  [1] * 3 +
-                  [10] * 4 +
-                  [0] * 4 +
-                  [13] +
-                  [7] * 5 +
-                  [np.nan] * 2], dtype=X_DTYPE).T
+    X = np.array(
+        [[4] * 500 + [1] * 3 + [10] * 4 + [0] * 4 + [13] + [7] * 5 + [np.nan] * 2],
+        dtype=X_DTYPE,
+    ).T
     known_categories = [np.unique(X[~np.isnan(X)])]
 
-    bin_mapper = _BinMapper(n_bins=n_bins,
-                            is_categorical=np.array([True]),
-                            known_categories=known_categories).fit(X)
+    bin_mapper = _BinMapper(
+        n_bins=n_bins,
+        is_categorical=np.array([True]),
+        known_categories=known_categories,
+    ).fit(X)
     assert bin_mapper.n_bins_non_missing_ == [6]
     assert_array_equal(bin_mapper.bin_thresholds_[0], [0, 1, 4, 7, 10, 13])
 
@@ -342,9 +373,11 @@ def test_categorical_with_numerical_features(n_bins):
     X = np.c_[X1, X2]
     known_categories = [None, np.unique(X2).astype(X_DTYPE)]
 
-    bin_mapper = _BinMapper(n_bins=n_bins,
-                            is_categorical=np.array([False, True]),
-                            known_categories=known_categories).fit(X)
+    bin_mapper = _BinMapper(
+        n_bins=n_bins,
+        is_categorical=np.array([False, True]),
+        known_categories=known_categories,
+    ).fit(X)
 
     assert_array_equal(bin_mapper.n_bins_non_missing_, [10, 5])
 
@@ -352,29 +385,32 @@ def test_categorical_with_numerical_features(n_bins):
     assert len(bin_thresholds) == 2
     assert_array_equal(bin_thresholds[1], np.arange(10, 15))
 
-    expected_X_trans = [[0, 0],
-                        [1, 1],
-                        [2, 2],
-                        [3, 3],
-                        [4, 4],
-                        [5, 0],
-                        [6, 1],
-                        [7, 2],
-                        [8, 3],
-                        [9, 4]]
+    expected_X_trans = [
+        [0, 0],
+        [1, 1],
+        [2, 2],
+        [3, 3],
+        [4, 4],
+        [5, 0],
+        [6, 1],
+        [7, 2],
+        [8, 3],
+        [9, 4],
+    ]
     assert_array_equal(bin_mapper.transform(X), expected_X_trans)
 
 
 def test_make_known_categories_bitsets():
     # Check the output of make_known_categories_bitsets
-    X = np.array([[14, 2, 30],
-                  [30, 4, 70],
-                  [40, 10, 180],
-                  [40, 240, 180]], dtype=X_DTYPE)
+    X = np.array(
+        [[14, 2, 30], [30, 4, 70], [40, 10, 180], [40, 240, 180]], dtype=X_DTYPE
+    )
 
-    bin_mapper = _BinMapper(n_bins=256,
-                            is_categorical=np.array([False, True, True]),
-                            known_categories=[None, X[:, 1], X[:, 2]])
+    bin_mapper = _BinMapper(
+        n_bins=256,
+        is_categorical=np.array([False, True, True]),
+        known_categories=[None, X[:, 1], X[:, 2]],
+    )
     bin_mapper.fit(X)
 
     known_cat_bitsets, f_idx_map = bin_mapper.make_known_categories_bitsets()
@@ -388,33 +424,38 @@ def test_make_known_categories_bitsets():
     # first categorical feature: [2, 4, 10, 240]
     f_idx = 1
     mapped_f_idx = f_idx_map[f_idx]
-    expected_cat_bitset[mapped_f_idx, 0] = 2**2 + 2**4 + 2**10
+    expected_cat_bitset[mapped_f_idx, 0] = 2 ** 2 + 2 ** 4 + 2 ** 10
     # 240 = 32**7 + 16, therefore the 16th bit of the 7th array is 1.
-    expected_cat_bitset[mapped_f_idx, 7] = 2**16
+    expected_cat_bitset[mapped_f_idx, 7] = 2 ** 16
 
     # second categorical feature [30, 70, 180]
     f_idx = 2
     mapped_f_idx = f_idx_map[f_idx]
-    expected_cat_bitset[mapped_f_idx, 0] = 2**30
-    expected_cat_bitset[mapped_f_idx, 2] = 2**6
-    expected_cat_bitset[mapped_f_idx, 5] = 2**20
+    expected_cat_bitset[mapped_f_idx, 0] = 2 ** 30
+    expected_cat_bitset[mapped_f_idx, 2] = 2 ** 6
+    expected_cat_bitset[mapped_f_idx, 5] = 2 ** 20
 
     assert_allclose(expected_cat_bitset, known_cat_bitsets)
 
 
-@pytest.mark.parametrize('is_categorical, known_categories, match', [
-    (np.array([True]), [None],
-     'Known categories for feature 0 must be provided'),
-
-    (np.array([False]), np.array([1, 2, 3]),
-     "isn't marked as a categorical feature, but categories were passed")
-])
+@pytest.mark.parametrize(
+    "is_categorical, known_categories, match",
+    [
+        (np.array([True]), [None], "Known categories for feature 0 must be provided"),
+        (
+            np.array([False]),
+            np.array([1, 2, 3]),
+            "isn't marked as a categorical feature, but categories were passed",
+        ),
+    ],
+)
 def test_categorical_parameters(is_categorical, known_categories, match):
     # test the validation of the is_categorical and known_categories parameters
 
     X = np.array([[1, 2, 3]], dtype=X_DTYPE)
 
-    bin_mapper = _BinMapper(is_categorical=is_categorical,
-                            known_categories=known_categories)
+    bin_mapper = _BinMapper(
+        is_categorical=is_categorical, known_categories=known_categories
+    )
     with pytest.raises(ValueError, match=match):
         bin_mapper.fit(X)
