@@ -11,15 +11,16 @@ from scipy import linalg
 
 from ._base import LinearModel, _rescale_data
 from ..base import RegressorMixin
+from ._base import _deprecate_normalize
 from ..utils.extmath import fast_logdet
 from scipy.linalg import pinvh
 from ..utils.validation import _check_sample_weight
-from ..utils.validation import _deprecate_positional_args
 
 
 ###############################################################################
 # BayesianRidge regression
 
+
 class BayesianRidge(RegressorMixin, LinearModel):
     """Bayesian ridge regression.
 
@@ -81,16 +82,19 @@ class BayesianRidge(RegressorMixin, LinearModel):
         If True, the regressors X will be normalized before regression by
         subtracting the mean and dividing by the l2-norm.
         If you wish to standardize, please use
-        :class:`sklearn.preprocessing.StandardScaler` before calling ``fit``
+        :class:`~sklearn.preprocessing.StandardScaler` before calling ``fit``
         on an estimator with ``normalize=False``.
 
+        .. deprecated:: 1.0
+            ``normalize`` was deprecated in version 1.0 and will be removed in
+            1.2.
+
     copy_X : bool, default=True
         If True, X will be copied; else, it may be overwritten.
 
     verbose : bool, default=False
         Verbose mode when fitting the model.
 
-
     Attributes
     ----------
     coef_ : array-like of shape (n_features,)
@@ -119,14 +123,28 @@ class BayesianRidge(RegressorMixin, LinearModel):
     n_iter_ : int
         The actual number of iterations to reach the stopping criterion.
 
-    Examples
+    X_offset_ : float
+        If `normalize=True`, offset subtracted for centering data to a
+        zero mean.
+
+    X_scale_ : float
+        If `normalize=True`, parameter used to scale data to a unit
+        standard deviation.
+
+    n_features_in_ : int
+        Number of features seen during :term:`fit`.
+
+        .. versionadded:: 0.24
+
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during :term:`fit`. Defined only when `X`
+        has feature names that are all strings.
+
+        .. versionadded:: 1.0
+
+    See Also
     --------
-    >>> from sklearn import linear_model
-    >>> clf = linear_model.BayesianRidge()
-    >>> clf.fit([[0,0], [1, 1], [2, 2]], [0, 1, 2])
-    BayesianRidge()
-    >>> clf.predict([[1, 1]])
-    array([1.])
+    ARDRegression : Bayesian ARD regression.
 
     Notes
     -----
@@ -145,12 +163,34 @@ class BayesianRidge(RegressorMixin, LinearModel):
 
     M. E. Tipping, Sparse Bayesian Learning and the Relevance Vector Machine,
     Journal of Machine Learning Research, Vol. 1, 2001.
+
+    Examples
+    --------
+    >>> from sklearn import linear_model
+    >>> clf = linear_model.BayesianRidge()
+    >>> clf.fit([[0,0], [1, 1], [2, 2]], [0, 1, 2])
+    BayesianRidge()
+    >>> clf.predict([[1, 1]])
+    array([1.])
     """
-    @_deprecate_positional_args
-    def __init__(self, *, n_iter=300, tol=1.e-3, alpha_1=1.e-6, alpha_2=1.e-6,
-                 lambda_1=1.e-6, lambda_2=1.e-6, alpha_init=None,
-                 lambda_init=None, compute_score=False, fit_intercept=True,
-                 normalize=False, copy_X=True, verbose=False):
+
+    def __init__(
+        self,
+        *,
+        n_iter=300,
+        tol=1.0e-3,
+        alpha_1=1.0e-6,
+        alpha_2=1.0e-6,
+        lambda_1=1.0e-6,
+        lambda_2=1.0e-6,
+        alpha_init=None,
+        lambda_init=None,
+        compute_score=False,
+        fit_intercept=True,
+        normalize="deprecated",
+        copy_X=True,
+        verbose=False,
+    ):
         self.n_iter = n_iter
         self.tol = tol
         self.alpha_1 = alpha_1
@@ -166,39 +206,50 @@ class BayesianRidge(RegressorMixin, LinearModel):
         self.verbose = verbose
 
     def fit(self, X, y, sample_weight=None):
-        """Fit the model
+        """Fit the model.
 
         Parameters
         ----------
         X : ndarray of shape (n_samples, n_features)
-            Training data
+            Training data.
         y : ndarray of shape (n_samples,)
-            Target values. Will be cast to X's dtype if necessary
+            Target values. Will be cast to X's dtype if necessary.
 
         sample_weight : ndarray of shape (n_samples,), default=None
-            Individual weights for each sample
+            Individual weights for each sample.
 
             .. versionadded:: 0.20
                parameter *sample_weight* support to BayesianRidge.
 
         Returns
         -------
-        self : returns an instance of self.
+        self : object
+            Returns the instance itself.
         """
+        self._normalize = _deprecate_normalize(
+            self.normalize, default=False, estimator_name=self.__class__.__name__
+        )
 
         if self.n_iter < 1:
-            raise ValueError('n_iter should be greater than or equal to 1.'
-                             ' Got {!r}.'.format(self.n_iter))
+            raise ValueError(
+                "n_iter should be greater than or equal to 1. Got {!r}.".format(
+                    self.n_iter
+                )
+            )
 
         X, y = self._validate_data(X, y, dtype=np.float64, y_numeric=True)
 
         if sample_weight is not None:
-            sample_weight = _check_sample_weight(sample_weight, X,
-                                                 dtype=X.dtype)
+            sample_weight = _check_sample_weight(sample_weight, X, dtype=X.dtype)
 
         X, y, X_offset_, y_offset_, X_scale_ = self._preprocess_data(
-            X, y, self.fit_intercept, self.normalize, self.copy_X,
-            sample_weight=sample_weight)
+            X,
+            y,
+            self.fit_intercept,
+            self._normalize,
+            self.copy_X,
+            sample_weight=sample_weight,
+        )
 
         if sample_weight is not None:
             # Sample weight can be implemented via a simple rescaling.
@@ -215,9 +266,9 @@ class BayesianRidge(RegressorMixin, LinearModel):
         alpha_ = self.alpha_init
         lambda_ = self.lambda_init
         if alpha_ is None:
-            alpha_ = 1. / (np.var(y) + eps)
+            alpha_ = 1.0 / (np.var(y) + eps)
         if lambda_ is None:
-            lambda_ = 1.
+            lambda_ = 1.0
 
         verbose = self.verbose
         lambda_1 = self.lambda_1
@@ -237,24 +288,20 @@ class BayesianRidge(RegressorMixin, LinearModel):
 
             # update posterior mean coef_ based on alpha_ and lambda_ and
             # compute corresponding rmse
-            coef_, rmse_ = self._update_coef_(X, y, n_samples, n_features,
-                                              XT_y, U, Vh, eigen_vals_,
-                                              alpha_, lambda_)
+            coef_, rmse_ = self._update_coef_(
+                X, y, n_samples, n_features, XT_y, U, Vh, eigen_vals_, alpha_, lambda_
+            )
             if self.compute_score:
                 # compute the log marginal likelihood
-                s = self._log_marginal_likelihood(n_samples, n_features,
-                                                  eigen_vals_,
-                                                  alpha_, lambda_,
-                                                  coef_, rmse_)
+                s = self._log_marginal_likelihood(
+                    n_samples, n_features, eigen_vals_, alpha_, lambda_, coef_, rmse_
+                )
                 self.scores_.append(s)
 
             # Update alpha and lambda according to (MacKay, 1992)
-            gamma_ = np.sum((alpha_ * eigen_vals_) /
-                            (lambda_ + alpha_ * eigen_vals_))
-            lambda_ = ((gamma_ + 2 * lambda_1) /
-                       (np.sum(coef_ ** 2) + 2 * lambda_2))
-            alpha_ = ((n_samples - gamma_ + 2 * alpha_1) /
-                      (rmse_ + 2 * alpha_2))
+            gamma_ = np.sum((alpha_ * eigen_vals_) / (lambda_ + alpha_ * eigen_vals_))
+            lambda_ = (gamma_ + 2 * lambda_1) / (np.sum(coef_ ** 2) + 2 * lambda_2)
+            alpha_ = (n_samples - gamma_ + 2 * alpha_1) / (rmse_ + 2 * alpha_2)
 
             # Check for convergence
             if iter_ != 0 and np.sum(np.abs(coef_old_ - coef_)) < self.tol:
@@ -269,23 +316,22 @@ class BayesianRidge(RegressorMixin, LinearModel):
         # log marginal likelihood and posterior covariance
         self.alpha_ = alpha_
         self.lambda_ = lambda_
-        self.coef_, rmse_ = self._update_coef_(X, y, n_samples, n_features,
-                                               XT_y, U, Vh, eigen_vals_,
-                                               alpha_, lambda_)
+        self.coef_, rmse_ = self._update_coef_(
+            X, y, n_samples, n_features, XT_y, U, Vh, eigen_vals_, alpha_, lambda_
+        )
         if self.compute_score:
             # compute the log marginal likelihood
-            s = self._log_marginal_likelihood(n_samples, n_features,
-                                              eigen_vals_,
-                                              alpha_, lambda_,
-                                              coef_, rmse_)
+            s = self._log_marginal_likelihood(
+                n_samples, n_features, eigen_vals_, alpha_, lambda_, coef_, rmse_
+            )
             self.scores_.append(s)
             self.scores_ = np.array(self.scores_)
 
         # posterior covariance is given by 1/alpha_ * scaled_sigma_
-        scaled_sigma_ = np.dot(Vh.T,
-                               Vh / (eigen_vals_ +
-                                     lambda_ / alpha_)[:, np.newaxis])
-        self.sigma_ = (1. / alpha_) * scaled_sigma_
+        scaled_sigma_ = np.dot(
+            Vh.T, Vh / (eigen_vals_ + lambda_ / alpha_)[:, np.newaxis]
+        )
+        self.sigma_ = (1.0 / alpha_) * scaled_sigma_
 
         self._set_intercept(X_offset_, y_offset_, X_scale_)
 
@@ -317,14 +363,15 @@ class BayesianRidge(RegressorMixin, LinearModel):
         if return_std is False:
             return y_mean
         else:
-            if self.normalize:
+            if self._normalize:
                 X = (X - self.X_offset_) / self.X_scale_
             sigmas_squared_data = (np.dot(X, self.sigma_) * X).sum(axis=1)
-            y_std = np.sqrt(sigmas_squared_data + (1. / self.alpha_))
+            y_std = np.sqrt(sigmas_squared_data + (1.0 / self.alpha_))
             return y_mean, y_std
 
-    def _update_coef_(self, X, y, n_samples, n_features, XT_y, U, Vh,
-                      eigen_vals_, alpha_, lambda_):
+    def _update_coef_(
+        self, X, y, n_samples, n_features, XT_y, U, Vh, eigen_vals_, alpha_, lambda_
+    ):
         """Update posterior mean and compute corresponding rmse.
 
         Posterior mean is given by coef_ = scaled_sigma_ * X.T * y where
@@ -333,21 +380,21 @@ class BayesianRidge(RegressorMixin, LinearModel):
         """
 
         if n_samples > n_features:
-            coef_ = np.dot(Vh.T,
-                           Vh / (eigen_vals_ +
-                                 lambda_ / alpha_)[:, np.newaxis])
-            coef_ = np.dot(coef_, XT_y)
+            coef_ = np.linalg.multi_dot(
+                [Vh.T, Vh / (eigen_vals_ + lambda_ / alpha_)[:, np.newaxis], XT_y]
+            )
         else:
-            coef_ = np.dot(X.T, np.dot(
-                U / (eigen_vals_ + lambda_ / alpha_)[None, :], U.T))
-            coef_ = np.dot(coef_, y)
+            coef_ = np.linalg.multi_dot(
+                [X.T, U / (eigen_vals_ + lambda_ / alpha_)[None, :], U.T, y]
+            )
 
         rmse_ = np.sum((y - np.dot(X, coef_)) ** 2)
 
         return coef_, rmse_
 
-    def _log_marginal_likelihood(self, n_samples, n_features, eigen_vals,
-                                 alpha_, lambda_, coef, rmse):
+    def _log_marginal_likelihood(
+        self, n_samples, n_features, eigen_vals, alpha_, lambda_, coef, rmse
+    ):
         """Log marginal likelihood."""
         alpha_1 = self.alpha_1
         alpha_2 = self.alpha_2
@@ -358,21 +405,22 @@ class BayesianRidge(RegressorMixin, LinearModel):
         # posterior covariance is given by
         # sigma = (lambda_ * np.eye(n_features) + alpha_ * np.dot(X.T, X))^-1
         if n_samples > n_features:
-            logdet_sigma = - np.sum(np.log(lambda_ + alpha_ * eigen_vals))
+            logdet_sigma = -np.sum(np.log(lambda_ + alpha_ * eigen_vals))
         else:
-            logdet_sigma = np.full(n_features, lambda_,
-                                   dtype=np.array(lambda_).dtype)
+            logdet_sigma = np.full(n_features, lambda_, dtype=np.array(lambda_).dtype)
             logdet_sigma[:n_samples] += alpha_ * eigen_vals
-            logdet_sigma = - np.sum(np.log(logdet_sigma))
+            logdet_sigma = -np.sum(np.log(logdet_sigma))
 
         score = lambda_1 * log(lambda_) - lambda_2 * lambda_
         score += alpha_1 * log(alpha_) - alpha_2 * alpha_
-        score += 0.5 * (n_features * log(lambda_) +
-                        n_samples * log(alpha_) -
-                        alpha_ * rmse -
-                        lambda_ * np.sum(coef ** 2) +
-                        logdet_sigma -
-                        n_samples * log(2 * np.pi))
+        score += 0.5 * (
+            n_features * log(lambda_)
+            + n_samples * log(alpha_)
+            - alpha_ * rmse
+            - lambda_ * np.sum(coef ** 2)
+            + logdet_sigma
+            - n_samples * log(2 * np.pi)
+        )
 
         return score
 
@@ -420,11 +468,11 @@ class ARDRegression(RegressorMixin, LinearModel):
         If True, compute the objective function at each step of the model.
 
     threshold_lambda : float, default=10 000
-        threshold for removing (pruning) weights with high precision from
+        Threshold for removing (pruning) weights with high precision from
         the computation.
 
     fit_intercept : bool, default=True
-        whether to calculate the intercept for this model. If set
+        Whether to calculate the intercept for this model. If set
         to false, no intercept will be used in calculations
         (i.e. data is expected to be centered).
 
@@ -433,9 +481,13 @@ class ARDRegression(RegressorMixin, LinearModel):
         If True, the regressors X will be normalized before regression by
         subtracting the mean and dividing by the l2-norm.
         If you wish to standardize, please use
-        :class:`sklearn.preprocessing.StandardScaler` before calling ``fit``
+        :class:`~sklearn.preprocessing.StandardScaler` before calling ``fit``
         on an estimator with ``normalize=False``.
 
+        .. deprecated:: 1.0
+            ``normalize`` was deprecated in version 1.0 and will be removed in
+            1.2.
+
     copy_X : bool, default=True
         If True, X will be copied; else, it may be overwritten.
 
@@ -463,14 +515,28 @@ class ARDRegression(RegressorMixin, LinearModel):
         Independent term in decision function. Set to 0.0 if
         ``fit_intercept = False``.
 
-    Examples
+    X_offset_ : float
+        If `normalize=True`, offset subtracted for centering data to a
+        zero mean.
+
+    X_scale_ : float
+        If `normalize=True`, parameter used to scale data to a unit
+        standard deviation.
+
+    n_features_in_ : int
+        Number of features seen during :term:`fit`.
+
+        .. versionadded:: 0.24
+
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during :term:`fit`. Defined only when `X`
+        has feature names that are all strings.
+
+        .. versionadded:: 1.0
+
+    See Also
     --------
-    >>> from sklearn import linear_model
-    >>> clf = linear_model.ARDRegression()
-    >>> clf.fit([[0,0], [1, 1], [2, 2]], [0, 1, 2])
-    ARDRegression()
-    >>> clf.predict([[1, 1]])
-    array([1.])
+    BayesianRidge : Bayesian ridge regression.
 
     Notes
     -----
@@ -489,12 +555,33 @@ class ARDRegression(RegressorMixin, LinearModel):
     ARD is a little different than the slide: only dimensions/features for
     which ``self.lambda_ < self.threshold_lambda`` are kept and the rest are
     discarded.
+
+    Examples
+    --------
+    >>> from sklearn import linear_model
+    >>> clf = linear_model.ARDRegression()
+    >>> clf.fit([[0,0], [1, 1], [2, 2]], [0, 1, 2])
+    ARDRegression()
+    >>> clf.predict([[1, 1]])
+    array([1.])
     """
-    @_deprecate_positional_args
-    def __init__(self, *, n_iter=300, tol=1.e-3, alpha_1=1.e-6, alpha_2=1.e-6,
-                 lambda_1=1.e-6, lambda_2=1.e-6, compute_score=False,
-                 threshold_lambda=1.e+4, fit_intercept=True, normalize=False,
-                 copy_X=True, verbose=False):
+
+    def __init__(
+        self,
+        *,
+        n_iter=300,
+        tol=1.0e-3,
+        alpha_1=1.0e-6,
+        alpha_2=1.0e-6,
+        lambda_1=1.0e-6,
+        lambda_2=1.0e-6,
+        compute_score=False,
+        threshold_lambda=1.0e4,
+        fit_intercept=True,
+        normalize="deprecated",
+        copy_X=True,
+        verbose=False,
+    ):
         self.n_iter = n_iter
         self.tol = tol
         self.fit_intercept = fit_intercept
@@ -509,31 +596,40 @@ class ARDRegression(RegressorMixin, LinearModel):
         self.verbose = verbose
 
     def fit(self, X, y):
-        """Fit the ARDRegression model according to the given training data
-        and parameters.
+        """Fit the model according to the given training data and parameters.
 
         Iterative procedure to maximize the evidence
 
         Parameters
         ----------
         X : array-like of shape (n_samples, n_features)
-            Training vector, where n_samples in the number of samples and
-            n_features is the number of features.
+            Training vector, where `n_samples` is the number of samples and
+            `n_features` is the number of features.
         y : array-like of shape (n_samples,)
-            Target values (integers). Will be cast to X's dtype if necessary
+            Target values (integers). Will be cast to X's dtype if necessary.
 
         Returns
         -------
-        self : returns an instance of self.
+        self : object
+            Fitted estimator.
         """
-        X, y = self._validate_data(X, y, dtype=np.float64, y_numeric=True,
-                                   ensure_min_samples=2)
+        self._normalize = _deprecate_normalize(
+            self.normalize, default=False, estimator_name=self.__class__.__name__
+        )
+
+        X, y = self._validate_data(
+            X, y, dtype=np.float64, y_numeric=True, ensure_min_samples=2
+        )
 
         n_samples, n_features = X.shape
         coef_ = np.zeros(n_features)
 
         X, y, X_offset_, y_offset_, X_scale_ = self._preprocess_data(
-            X, y, self.fit_intercept, self.normalize, self.copy_X)
+            X, y, self.fit_intercept, self._normalize, self.copy_X
+        )
+
+        self.X_offset_ = X_offset_
+        self.X_scale_ = X_scale_
 
         # Launch the convergence loop
         keep_lambda = np.ones(n_features, dtype=bool)
@@ -548,19 +644,23 @@ class ARDRegression(RegressorMixin, LinearModel):
         eps = np.finfo(np.float64).eps
         # Add `eps` in the denominator to omit division by zero if `np.var(y)`
         # is zero
-        alpha_ = 1. / (np.var(y) + eps)
+        alpha_ = 1.0 / (np.var(y) + eps)
         lambda_ = np.ones(n_features)
 
         self.scores_ = list()
         coef_old_ = None
 
         def update_coeff(X, y, coef_, alpha_, keep_lambda, sigma_):
-            coef_[keep_lambda] = alpha_ * np.dot(
-                sigma_, np.dot(X[:, keep_lambda].T, y))
+            coef_[keep_lambda] = alpha_ * np.linalg.multi_dot(
+                [sigma_, X[:, keep_lambda].T, y]
+            )
             return coef_
 
-        update_sigma = (self._update_sigma if n_samples >= n_features
-                        else self._update_sigma_woodbury)
+        update_sigma = (
+            self._update_sigma
+            if n_samples >= n_features
+            else self._update_sigma_woodbury
+        )
         # Iterative procedure of ARDRegression
         for iter_ in range(self.n_iter):
             sigma_ = update_sigma(X, alpha_, lambda_, keep_lambda)
@@ -568,12 +668,13 @@ class ARDRegression(RegressorMixin, LinearModel):
 
             # Update alpha and lambda
             rmse_ = np.sum((y - np.dot(X, coef_)) ** 2)
-            gamma_ = 1. - lambda_[keep_lambda] * np.diag(sigma_)
-            lambda_[keep_lambda] = ((gamma_ + 2. * lambda_1) /
-                                    ((coef_[keep_lambda]) ** 2 +
-                                     2. * lambda_2))
-            alpha_ = ((n_samples - gamma_.sum() + 2. * alpha_1) /
-                      (rmse_ + 2. * alpha_2))
+            gamma_ = 1.0 - lambda_[keep_lambda] * np.diag(sigma_)
+            lambda_[keep_lambda] = (gamma_ + 2.0 * lambda_1) / (
+                (coef_[keep_lambda]) ** 2 + 2.0 * lambda_2
+            )
+            alpha_ = (n_samples - gamma_.sum() + 2.0 * alpha_1) / (
+                rmse_ + 2.0 * alpha_2
+            )
 
             # Prune the weights with a precision over a threshold
             keep_lambda = lambda_ < self.threshold_lambda
@@ -583,8 +684,11 @@ class ARDRegression(RegressorMixin, LinearModel):
             if self.compute_score:
                 s = (lambda_1 * np.log(lambda_) - lambda_2 * lambda_).sum()
                 s += alpha_1 * log(alpha_) - alpha_2 * alpha_
-                s += 0.5 * (fast_logdet(sigma_) + n_samples * log(alpha_) +
-                            np.sum(np.log(lambda_)))
+                s += 0.5 * (
+                    fast_logdet(sigma_)
+                    + n_samples * log(alpha_)
+                    + np.sum(np.log(lambda_))
+                )
                 s -= 0.5 * (alpha_ * rmse_ + (lambda_ * coef_ ** 2).sum())
                 self.scores_.append(s)
 
@@ -625,8 +729,8 @@ class ARDRegression(RegressorMixin, LinearModel):
             np.eye(n_samples) / alpha_ + np.dot(X_keep * inv_lambda, X_keep.T)
         )
         sigma_ = np.dot(sigma_, X_keep * inv_lambda)
-        sigma_ = - np.dot(inv_lambda.reshape(-1, 1) * X_keep.T, sigma_)
-        sigma_[np.diag_indices(sigma_.shape[1])] += 1. / lambda_[keep_lambda]
+        sigma_ = -np.dot(inv_lambda.reshape(-1, 1) * X_keep.T, sigma_)
+        sigma_[np.diag_indices(sigma_.shape[1])] += 1.0 / lambda_[keep_lambda]
         return sigma_
 
     def _update_sigma(self, X, alpha_, lambda_, keep_lambda):
@@ -666,9 +770,9 @@ class ARDRegression(RegressorMixin, LinearModel):
         if return_std is False:
             return y_mean
         else:
-            if self.normalize:
+            if self._normalize:
                 X = (X - self.X_offset_) / self.X_scale_
             X = X[:, self.lambda_ < self.threshold_lambda]
             sigmas_squared_data = (np.dot(X, self.sigma_) * X).sum(axis=1)
-            y_std = np.sqrt(sigmas_squared_data + (1. / self.alpha_))
+            y_std = np.sqrt(sigmas_squared_data + (1.0 / self.alpha_))
             return y_mean, y_std
