@@ -67,8 +67,10 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <climits>
 #include <random>
 #include "svm.h"
+#include "_svm_cython_blas_helpers.h"
 #include "../newrand/newrand.h"
 
+
 #ifndef _LIBSVM_CPP
 typedef float Qfloat;
 typedef signed char schar;
@@ -289,14 +291,14 @@ public:
 class Kernel: public QMatrix {
 public:
 #ifdef _DENSE_REP
-	Kernel(int l, PREFIX(node) * x, const svm_parameter& param);
+	Kernel(int l, PREFIX(node) * x, const svm_parameter& param, BlasFunctions *blas_functions);
 #else
-	Kernel(int l, PREFIX(node) * const * x, const svm_parameter& param);
+	Kernel(int l, PREFIX(node) * const * x, const svm_parameter& param, BlasFunctions *blas_functions);
 #endif
 	virtual ~Kernel();
 
 	static double k_function(const PREFIX(node) *x, const PREFIX(node) *y,
-				 const svm_parameter& param);
+				 const svm_parameter& param, BlasFunctions *blas_functions);
 	virtual Qfloat *get_Q(int column, int len) const = 0;
 	virtual double *get_QD() const = 0;
 	virtual void swap_index(int i, int j) const	// no so const...
@@ -315,6 +317,8 @@ private:
 	const PREFIX(node) **x;
 #endif
 	double *x_square;
+	// scipy blas pointer
+	BlasFunctions *m_blas;
 
 	// svm_parameter
 	const int kernel_type;
@@ -322,26 +326,26 @@ private:
 	const double gamma;
 	const double coef0;
 
-	static double dot(const PREFIX(node) *px, const PREFIX(node) *py);
+	static double dot(const PREFIX(node) *px, const PREFIX(node) *py, BlasFunctions *blas_functions);
 #ifdef _DENSE_REP
-	static double dot(const PREFIX(node) &px, const PREFIX(node) &py);
+	static double dot(const PREFIX(node) &px, const PREFIX(node) &py, BlasFunctions *blas_functions);
 #endif
 
 	double kernel_linear(int i, int j) const
 	{
-		return dot(x[i],x[j]);
+		return dot(x[i],x[j],m_blas);
 	}
 	double kernel_poly(int i, int j) const
 	{
-		return powi(gamma*dot(x[i],x[j])+coef0,degree);
+		return powi(gamma*dot(x[i],x[j],m_blas)+coef0,degree);
 	}
 	double kernel_rbf(int i, int j) const
 	{
-		return exp(-gamma*(x_square[i]+x_square[j]-2*dot(x[i],x[j])));
+		return exp(-gamma*(x_square[i]+x_square[j]-2*dot(x[i],x[j],m_blas)));
 	}
 	double kernel_sigmoid(int i, int j) const
 	{
-		return tanh(gamma*dot(x[i],x[j])+coef0);
+		return tanh(gamma*dot(x[i],x[j],m_blas)+coef0);
 	}
 	double kernel_precomputed(int i, int j) const
 	{
@@ -354,13 +358,14 @@ private:
 };
 
 #ifdef _DENSE_REP
-Kernel::Kernel(int l, PREFIX(node) * x_, const svm_parameter& param)
+Kernel::Kernel(int l, PREFIX(node) * x_, const svm_parameter& param, BlasFunctions *blas_functions)
 #else
-Kernel::Kernel(int l, PREFIX(node) * const * x_, const svm_parameter& param)
+Kernel::Kernel(int l, PREFIX(node) * const * x_, const svm_parameter& param, BlasFunctions *blas_functions)
 #endif
 :kernel_type(param.kernel_type), degree(param.degree),
  gamma(param.gamma), coef0(param.coef0)
 {
+	m_blas = blas_functions;
 	switch(kernel_type)
 	{
 		case LINEAR:
@@ -386,7 +391,7 @@ Kernel::Kernel(int l, PREFIX(node) * const * x_, const svm_parameter& param)
 	{
 		x_square = new double[l];
 		for(int i=0;i<l;i++)
-			x_square[i] = dot(x[i],x[i]);
+			x_square[i] = dot(x[i],x[i],blas_functions);
 	}
 	else
 		x_square = 0;
@@ -399,27 +404,25 @@ Kernel::~Kernel()
 }
 
 #ifdef _DENSE_REP
-double Kernel::dot(const PREFIX(node) *px, const PREFIX(node) *py)
+double Kernel::dot(const PREFIX(node) *px, const PREFIX(node) *py, BlasFunctions *blas_functions)
 {
 	double sum = 0;
 
 	int dim = min(px->dim, py->dim);
-	for (int i = 0; i < dim; i++)
-		sum += (px->values)[i] * (py->values)[i];
+	sum = blas_functions->dot(dim, px->values, 1, py->values, 1);
 	return sum;
 }
 
-double Kernel::dot(const PREFIX(node) &px, const PREFIX(node) &py)
+double Kernel::dot(const PREFIX(node) &px, const PREFIX(node) &py, BlasFunctions *blas_functions)
 {
 	double sum = 0;
 
 	int dim = min(px.dim, py.dim);
-	for (int i = 0; i < dim; i++)
-		sum += px.values[i] * py.values[i];
+	sum = blas_functions->dot(dim, px.values, 1, py.values, 1);
 	return sum;
 }
 #else
-double Kernel::dot(const PREFIX(node) *px, const PREFIX(node) *py)
+double Kernel::dot(const PREFIX(node) *px, const PREFIX(node) *py, BlasFunctions *blas_functions)
 {
 	double sum = 0;
 	while(px->index != -1 && py->index != -1)
@@ -443,24 +446,26 @@ double Kernel::dot(const PREFIX(node) *px, const PREFIX(node) *py)
 #endif
 
 double Kernel::k_function(const PREFIX(node) *x, const PREFIX(node) *y,
-			  const svm_parameter& param)
+			  const svm_parameter& param, BlasFunctions *blas_functions)
 {
 	switch(param.kernel_type)
 	{
 		case LINEAR:
-			return dot(x,y);
+			return dot(x,y,blas_functions);
 		case POLY:
-			return powi(param.gamma*dot(x,y)+param.coef0,param.degree);
+			return powi(param.gamma*dot(x,y,blas_functions)+param.coef0,param.degree);
 		case RBF:
 		{
 			double sum = 0;
 #ifdef _DENSE_REP
 			int dim = min(x->dim, y->dim), i;
+			double* m_array = (double*)malloc(sizeof(double)*dim);
 			for (i = 0; i < dim; i++)
 			{
-				double d = x->values[i] - y->values[i];
-				sum += d*d;
+				m_array[i] = x->values[i] - y->values[i];
 			}
+			sum = blas_functions->dot(dim, m_array, 1, m_array, 1);
+			free(m_array);
 			for (; i < x->dim; i++)
 				sum += x->values[i] * x->values[i];
 			for (; i < y->dim; i++)
@@ -505,7 +510,7 @@ double Kernel::k_function(const PREFIX(node) *x, const PREFIX(node) *y,
 			return exp(-param.gamma*sum);
 		}
 		case SIGMOID:
-			return tanh(param.gamma*dot(x,y)+param.coef0);
+			return tanh(param.gamma*dot(x,y,blas_functions)+param.coef0);
 		case PRECOMPUTED:  //x: test (validation), y: SV
                     {
 #ifdef _DENSE_REP
@@ -518,7 +523,6 @@ double Kernel::k_function(const PREFIX(node) *x, const PREFIX(node) *y,
 			return 0;  // Unreachable 
 	}
 }
-
 // An SMO algorithm in Fan et al., JMLR 6(2005), p. 1889--1918
 // Solves:
 //
@@ -1411,8 +1415,8 @@ double Solver_NU::calculate_rho()
 class SVC_Q: public Kernel
 { 
 public:
-	SVC_Q(const PREFIX(problem)& prob, const svm_parameter& param, const schar *y_)
-	:Kernel(prob.l, prob.x, param)
+	SVC_Q(const PREFIX(problem)& prob, const svm_parameter& param, const schar *y_, BlasFunctions *blas_functions)
+	:Kernel(prob.l, prob.x, param, blas_functions)
 	{
 		clone(y,y_,prob.l);
 		cache = new Cache(prob.l,(long int)(param.cache_size*(1<<20)));
@@ -1461,8 +1465,8 @@ private:
 class ONE_CLASS_Q: public Kernel
 {
 public:
-	ONE_CLASS_Q(const PREFIX(problem)& prob, const svm_parameter& param)
-	:Kernel(prob.l, prob.x, param)
+	ONE_CLASS_Q(const PREFIX(problem)& prob, const svm_parameter& param, BlasFunctions *blas_functions)
+	:Kernel(prob.l, prob.x, param, blas_functions)
 	{
 		cache = new Cache(prob.l,(long int)(param.cache_size*(1<<20)));
 		QD = new double[prob.l];
@@ -1507,8 +1511,8 @@ private:
 class SVR_Q: public Kernel
 { 
 public:
-	SVR_Q(const PREFIX(problem)& prob, const svm_parameter& param)
-	:Kernel(prob.l, prob.x, param)
+	SVR_Q(const PREFIX(problem)& prob, const svm_parameter& param, BlasFunctions *blas_functions)
+	:Kernel(prob.l, prob.x, param, blas_functions)
 	{
 		l = prob.l;
 		cache = new Cache(l,(long int)(param.cache_size*(1<<20)));
@@ -1584,7 +1588,7 @@ private:
 //
 static void solve_c_svc(
 	const PREFIX(problem) *prob, const svm_parameter* param,
-	double *alpha, Solver::SolutionInfo* si, double Cp, double Cn)
+	double *alpha, Solver::SolutionInfo* si, double Cp, double Cn, BlasFunctions *blas_functions)
 {
 	int l = prob->l;
 	double *minus_ones = new double[l];
@@ -1610,7 +1614,7 @@ static void solve_c_svc(
 	}
 
 	Solver s;
-	s.Solve(l, SVC_Q(*prob,*param,y), minus_ones, y,
+	s.Solve(l, SVC_Q(*prob,*param,y, blas_functions), minus_ones, y,
 		alpha, C, param->eps, si, param->shrinking,
                 param->max_iter);
 
@@ -1633,7 +1637,7 @@ static void solve_c_svc(
 
 static void solve_nu_svc(
 	const PREFIX(problem) *prob, const svm_parameter *param,
-	double *alpha, Solver::SolutionInfo* si)
+	double *alpha, Solver::SolutionInfo* si, BlasFunctions *blas_functions)
 {
 	int i;
 	int l = prob->l;
@@ -1675,7 +1679,7 @@ static void solve_nu_svc(
 		zeros[i] = 0;
 
 	Solver_NU s;
-	s.Solve(l, SVC_Q(*prob,*param,y), zeros, y,
+	s.Solve(l, SVC_Q(*prob,*param,y,blas_functions), zeros, y,
 		alpha, C, param->eps, si,  param->shrinking, param->max_iter);
 	double r = si->r;
 
@@ -1697,7 +1701,7 @@ static void solve_nu_svc(
 
 static void solve_one_class(
 	const PREFIX(problem) *prob, const svm_parameter *param,
-	double *alpha, Solver::SolutionInfo* si)
+	double *alpha, Solver::SolutionInfo* si, BlasFunctions *blas_functions)
 {
 	int l = prob->l;
 	double *zeros = new double[l];
@@ -1730,7 +1734,7 @@ static void solve_one_class(
 	}
 
 	Solver s;
-	s.Solve(l, ONE_CLASS_Q(*prob,*param), zeros, ones,
+	s.Solve(l, ONE_CLASS_Q(*prob,*param,blas_functions), zeros, ones,
 		alpha, C, param->eps, si, param->shrinking, param->max_iter);
 
         delete[] C;
@@ -1740,7 +1744,7 @@ static void solve_one_class(
 
 static void solve_epsilon_svr(
 	const PREFIX(problem) *prob, const svm_parameter *param,
-	double *alpha, Solver::SolutionInfo* si)
+	double *alpha, Solver::SolutionInfo* si, BlasFunctions *blas_functions)
 {
 	int l = prob->l;
 	double *alpha2 = new double[2*l];
@@ -1763,7 +1767,7 @@ static void solve_epsilon_svr(
 	}
 
 	Solver s;
-	s.Solve(2*l, SVR_Q(*prob,*param), linear_term, y,
+	s.Solve(2*l, SVR_Q(*prob,*param,blas_functions), linear_term, y,
 		alpha2, C, param->eps, si, param->shrinking, param->max_iter);
 
 	double sum_alpha = 0;
@@ -1782,7 +1786,7 @@ static void solve_epsilon_svr(
 
 static void solve_nu_svr(
 	const PREFIX(problem) *prob, const svm_parameter *param,
-	double *alpha, Solver::SolutionInfo* si)
+	double *alpha, Solver::SolutionInfo* si, BlasFunctions *blas_functions)
 {
 	int l = prob->l;
 	double *C = new double[2*l];
@@ -1812,7 +1816,7 @@ static void solve_nu_svr(
 	}
 
 	Solver_NU s;
-	s.Solve(2*l, SVR_Q(*prob,*param), linear_term, y,
+	s.Solve(2*l, SVR_Q(*prob,*param,blas_functions), linear_term, y,
 		alpha2, C, param->eps, si, param->shrinking, param->max_iter);
 
 	info("epsilon = %f\n",-si->r);
@@ -1837,7 +1841,7 @@ struct decision_function
 
 static decision_function svm_train_one(
 	const PREFIX(problem) *prob, const svm_parameter *param,
-	double Cp, double Cn, int *status)
+	double Cp, double Cn, int *status, BlasFunctions *blas_functions)
 {
 	double *alpha = Malloc(double,prob->l);
 	Solver::SolutionInfo si;
@@ -1845,23 +1849,23 @@ static decision_function svm_train_one(
 	{
  		case C_SVC:
 			si.upper_bound = Malloc(double,prob->l); 
- 			solve_c_svc(prob,param,alpha,&si,Cp,Cn);
+ 			solve_c_svc(prob,param,alpha,&si,Cp,Cn,blas_functions);
  			break;
  		case NU_SVC:
 			si.upper_bound = Malloc(double,prob->l); 
- 			solve_nu_svc(prob,param,alpha,&si);
+ 			solve_nu_svc(prob,param,alpha,&si,blas_functions);
  			break;
  		case ONE_CLASS:
 			si.upper_bound = Malloc(double,prob->l); 
- 			solve_one_class(prob,param,alpha,&si);
+ 			solve_one_class(prob,param,alpha,&si,blas_functions);
  			break;
  		case EPSILON_SVR:
 			si.upper_bound = Malloc(double,2*prob->l); 
- 			solve_epsilon_svr(prob,param,alpha,&si);
+ 			solve_epsilon_svr(prob,param,alpha,&si,blas_functions);
  			break;
  		case NU_SVR:
 			si.upper_bound = Malloc(double,2*prob->l); 
- 			solve_nu_svr(prob,param,alpha,&si);
+ 			solve_nu_svr(prob,param,alpha,&si,blas_functions);
  			break;
 	}
 
@@ -2092,7 +2096,7 @@ static void multiclass_probability(int k, double **r, double *p)
 // Cross-validation decision values for probability estimates
 static void svm_binary_svc_probability(
 	const PREFIX(problem) *prob, const svm_parameter *param,
-	double Cp, double Cn, double& probA, double& probB, int * status)
+	double Cp, double Cn, double& probA, double& probB, int * status, BlasFunctions *blas_functions)
 {
 	int i;
 	int nr_fold = 5;
@@ -2165,13 +2169,13 @@ static void svm_binary_svc_probability(
 			subparam.weight_label[1]=-1;
 			subparam.weight[0]=Cp;
 			subparam.weight[1]=Cn;
-			struct PREFIX(model) *submodel = PREFIX(train)(&subprob,&subparam, status);
+			struct PREFIX(model) *submodel = PREFIX(train)(&subprob,&subparam, status, blas_functions);
 			for(j=begin;j<end;j++)
 			{
 #ifdef _DENSE_REP
-                                PREFIX(predict_values)(submodel,(prob->x+perm[j]),&(dec_values[perm[j]])); 
+                                PREFIX(predict_values)(submodel,(prob->x+perm[j]),&(dec_values[perm[j]]), blas_functions); 
 #else
-				PREFIX(predict_values)(submodel,prob->x[perm[j]],&(dec_values[perm[j]])); 
+				PREFIX(predict_values)(submodel,prob->x[perm[j]],&(dec_values[perm[j]]), blas_functions); 
 #endif
 				// ensure +1 -1 order; reason not using CV subroutine
 				dec_values[perm[j]] *= submodel->label[0];
@@ -2190,7 +2194,7 @@ static void svm_binary_svc_probability(
 
 // Return parameter of a Laplace distribution 
 static double svm_svr_probability(
-	const PREFIX(problem) *prob, const svm_parameter *param)
+	const PREFIX(problem) *prob, const svm_parameter *param, BlasFunctions *blas_functions)
 {
 	int i;
 	int nr_fold = 5;
@@ -2201,7 +2205,7 @@ static double svm_svr_probability(
 	newparam.probability = 0;
     newparam.random_seed = -1; // This is called from train, which already sets
                                // the seed.
-	PREFIX(cross_validation)(prob,&newparam,nr_fold,ymv);
+	PREFIX(cross_validation)(prob,&newparam,nr_fold,ymv, blas_functions);
 	for(i=0;i<prob->l;i++)
 	{
 		ymv[i]=prob->y[i]-ymv[i];
@@ -2346,7 +2350,7 @@ static void remove_zero_weight(PREFIX(problem) *newprob, const PREFIX(problem) *
 // Interface functions
 //
 PREFIX(model) *PREFIX(train)(const PREFIX(problem) *prob, const svm_parameter *param,
-        int *status)
+        int *status, BlasFunctions *blas_functions)
 {
 	PREFIX(problem) newprob;
 	remove_zero_weight(&newprob, prob);
@@ -2377,10 +2381,10 @@ PREFIX(model) *PREFIX(train)(const PREFIX(problem) *prob, const svm_parameter *p
 		    param->svm_type == NU_SVR))
 		{
 			model->probA = Malloc(double,1);
-			model->probA[0] = NAMESPACE::svm_svr_probability(prob,param);
+			model->probA[0] = NAMESPACE::svm_svr_probability(prob,param,blas_functions);
 		}
 
-                NAMESPACE::decision_function f = NAMESPACE::svm_train_one(prob,param,0,0, status);
+                NAMESPACE::decision_function f = NAMESPACE::svm_train_one(prob,param,0,0, status,blas_functions);
 		model->rho = Malloc(double,1);
 		model->rho[0] = f.rho;
 
@@ -2495,9 +2499,9 @@ PREFIX(model) *PREFIX(train)(const PREFIX(problem) *prob, const svm_parameter *p
 				}
 
 				if(param->probability)
-                                    NAMESPACE::svm_binary_svc_probability(&sub_prob,param,weighted_C[i],weighted_C[j],probA[p],probB[p], status);
+                                    NAMESPACE::svm_binary_svc_probability(&sub_prob,param,weighted_C[i],weighted_C[j],probA[p],probB[p], status, blas_functions);
 
-				f[p] = NAMESPACE::svm_train_one(&sub_prob,param,weighted_C[i],weighted_C[j], status);
+				f[p] = NAMESPACE::svm_train_one(&sub_prob,param,weighted_C[i],weighted_C[j], status, blas_functions);
 				for(k=0;k<ci;k++)
 					if(!nonzero[si+k] && fabs(f[p].alpha[k]) > 0)
 						nonzero[si+k] = true;
@@ -2629,7 +2633,7 @@ PREFIX(model) *PREFIX(train)(const PREFIX(problem) *prob, const svm_parameter *p
 }
 
 // Stratified cross validation
-void PREFIX(cross_validation)(const PREFIX(problem) *prob, const svm_parameter *param, int nr_fold, double *target)
+void PREFIX(cross_validation)(const PREFIX(problem) *prob, const svm_parameter *param, int nr_fold, double *target, BlasFunctions *blas_functions)
 {
 	int i;
 	int *fold_start = Malloc(int,nr_fold+1);
@@ -2736,25 +2740,25 @@ void PREFIX(cross_validation)(const PREFIX(problem) *prob, const svm_parameter *
 			++k;
 		}
                 int dummy_status = 0; // IGNORES TIMEOUT ERRORS
-		struct PREFIX(model) *submodel = PREFIX(train)(&subprob,param, &dummy_status);
+		struct PREFIX(model) *submodel = PREFIX(train)(&subprob,param, &dummy_status, blas_functions);
 		if(param->probability && 
 		   (param->svm_type == C_SVC || param->svm_type == NU_SVC))
 		{
 			double *prob_estimates=Malloc(double, PREFIX(get_nr_class)(submodel));
 			for(j=begin;j<end;j++)
 #ifdef _DENSE_REP
-				target[perm[j]] = PREFIX(predict_probability)(submodel,(prob->x + perm[j]),prob_estimates);
+				target[perm[j]] = PREFIX(predict_probability)(submodel,(prob->x + perm[j]),prob_estimates, blas_functions);
 #else
-                                target[perm[j]] = PREFIX(predict_probability)(submodel,prob->x[perm[j]],prob_estimates);
+                                target[perm[j]] = PREFIX(predict_probability)(submodel,prob->x[perm[j]],prob_estimates, blas_functions);
 #endif
 			free(prob_estimates);			
 		}
 		else
 			for(j=begin;j<end;j++)
 #ifdef _DENSE_REP
-				target[perm[j]] = PREFIX(predict)(submodel,prob->x+perm[j]);
+				target[perm[j]] = PREFIX(predict)(submodel,prob->x+perm[j],blas_functions);
 #else
-                target[perm[j]] = PREFIX(predict)(submodel,prob->x[perm[j]]);
+                target[perm[j]] = PREFIX(predict)(submodel,prob->x[perm[j]],blas_functions);
 #endif
 		PREFIX(free_and_destroy_model)(&submodel);
 		free(subprob.x);
@@ -2795,7 +2799,7 @@ double PREFIX(get_svr_probability)(const PREFIX(model) *model)
 	}
 }
 
-double PREFIX(predict_values)(const PREFIX(model) *model, const PREFIX(node) *x, double* dec_values)
+double PREFIX(predict_values)(const PREFIX(model) *model, const PREFIX(node) *x, double* dec_values, BlasFunctions *blas_functions)
 {
 	int i;
 	if(model->param.svm_type == ONE_CLASS ||
@@ -2807,9 +2811,9 @@ double PREFIX(predict_values)(const PREFIX(model) *model, const PREFIX(node) *x,
 		
 		for(i=0;i<model->l;i++)
 #ifdef _DENSE_REP
-                    sum += sv_coef[i] * NAMESPACE::Kernel::k_function(x,model->SV+i,model->param);
+                    sum += sv_coef[i] * NAMESPACE::Kernel::k_function(x,model->SV+i,model->param,blas_functions);
 #else
-                sum += sv_coef[i] * NAMESPACE::Kernel::k_function(x,model->SV[i],model->param);
+                sum += sv_coef[i] * NAMESPACE::Kernel::k_function(x,model->SV[i],model->param,blas_functions);
 #endif
 		sum -= model->rho[0];
 		*dec_values = sum;
@@ -2827,9 +2831,9 @@ double PREFIX(predict_values)(const PREFIX(model) *model, const PREFIX(node) *x,
 		double *kvalue = Malloc(double,l);
 		for(i=0;i<l;i++)
 #ifdef _DENSE_REP
-                    kvalue[i] = NAMESPACE::Kernel::k_function(x,model->SV+i,model->param);
+                    kvalue[i] = NAMESPACE::Kernel::k_function(x,model->SV+i,model->param,blas_functions);
 #else
-                kvalue[i] = NAMESPACE::Kernel::k_function(x,model->SV[i],model->param);
+                kvalue[i] = NAMESPACE::Kernel::k_function(x,model->SV[i],model->param,blas_functions);
 #endif
 
 		int *start = Malloc(int,nr_class);
@@ -2880,7 +2884,7 @@ double PREFIX(predict_values)(const PREFIX(model) *model, const PREFIX(node) *x,
 	}
 }
 
-double PREFIX(predict)(const PREFIX(model) *model, const PREFIX(node) *x)
+double PREFIX(predict)(const PREFIX(model) *model, const PREFIX(node) *x, BlasFunctions *blas_functions)
 {
 	int nr_class = model->nr_class;
 	double *dec_values;
@@ -2890,13 +2894,13 @@ double PREFIX(predict)(const PREFIX(model) *model, const PREFIX(node) *x)
 		dec_values = Malloc(double, 1);
 	else 
 		dec_values = Malloc(double, nr_class*(nr_class-1)/2);
-	double pred_result = PREFIX(predict_values)(model, x, dec_values);
+	double pred_result = PREFIX(predict_values)(model, x, dec_values, blas_functions);
 	free(dec_values);
 	return pred_result;
 }
 
 double PREFIX(predict_probability)(
-	const PREFIX(model) *model, const PREFIX(node) *x, double *prob_estimates)
+	const PREFIX(model) *model, const PREFIX(node) *x, double *prob_estimates, BlasFunctions *blas_functions)
 {
 	if ((model->param.svm_type == C_SVC || model->param.svm_type == NU_SVC) &&
 	    model->probA!=NULL && model->probB!=NULL)
@@ -2904,7 +2908,7 @@ double PREFIX(predict_probability)(
 		int i;
 		int nr_class = model->nr_class;
 		double *dec_values = Malloc(double, nr_class*(nr_class-1)/2);
-		PREFIX(predict_values)(model, x, dec_values);
+		PREFIX(predict_values)(model, x, dec_values, blas_functions);
 
 		double min_prob=1e-7;
 		double **pairwise_prob=Malloc(double *,nr_class);
@@ -2931,7 +2935,7 @@ double PREFIX(predict_probability)(
 		return model->label[prob_max_idx];
 	}
 	else 
-		return PREFIX(predict)(model, x);
+		return PREFIX(predict)(model, x, blas_functions);
 }
 
 
